#!/bin/sh
# Copyright (c) 2018 Synology Inc. All rights reserved.

UNINSTALL_VMM_TITLE="卸载 Virtual Machine Manager"
CONFIRM_UNINSTALL_LABEL="确认卸载"
EXIST_DATA_SUGGEST_DESC="卸载 Virtual Machine Manager 不会移除虚拟硬盘和映像。如果要删除数据，请返回到套件以执行相关操作。<br>注：卸载并重新安装套件可作为解决 Virtual Machine Manager 错误问题的一种方法。"
MIGHT_MINOR_OTHER_HOST_DESC="此 Synology NAS 属于 Virtual Machine Manager 集群。卸载套件之后，主机将不再处于原始集群中，而只显示为离线。在线主机数低于一半时，集群将会冻结。"
LOCAL_VM_RUNNING_OR_LOCAL_STORAGE_USING_DESC="仍有虚拟机在运行。卸载将暂停 5 分钟，以便虚拟机关机，否则 5 分钟之后将会强制关闭虚拟机。"
CCC_GUEST_TOOL="/var/packages/Virtualization/target/bin/synocccguest"

jsOut="[{
	\"step_title\": \"${UNINSTALL_VMM_TITLE}\",
	\"items\": [{
		\"type\": \"multiselect\",
		\"desc\": \"${EXIST_DATA_SUGGEST_DESC}\",
		\"subitems\": []
	}]
}]"
index=1

AppendStepArray()
{
	for item in $@
	do
		jsNew=""
		case $item in
			"might_minor_other_host_desc")
				jsNew="{
						\"step_title\": \"${UNINSTALL_VMM_TITLE}\",
						\"invalid_next_disabled\": true,
						\"items\": [{
							\"type\": \"multiselect\",
							\"desc\": \"${MIGHT_MINOR_OTHER_HOST_DESC}\",
							\"subitems\": [{
								\"desc\": \"${CONFIRM_UNINSTALL_LABEL}\",
								\"validator\": {
									\"fn\": \"{return true === arguments[0];}\"
								}
							}]
						}]
					}"
				;;
			"local_vm_running_or_local_storage_using_desc")
				jsNew="{
						\"step_title\": \"${UNINSTALL_VMM_TITLE}\",
						\"invalid_next_disabled\": true,
						\"items\": [{
							\"type\": \"multiselect\",
							\"desc\": \"${LOCAL_VM_RUNNING_OR_LOCAL_STORAGE_USING_DESC}\",
							\"subitems\": [{
								\"desc\": \"${CONFIRM_UNINSTALL_LABEL}\",
								\"validator\": {
									\"fn\": \"{return true === arguments[0];}\"
								}
							}]
						}]
					}"
				;;
			*)
				echo "Unknown parameter ${item}"
				;;
		esac
		if [ -n "$jsNew" ]; then
			jsOut=`/bin/echo "${jsOut}" | jq --argjson jsNew "${jsNew}" --argjson index "${index}" '.[$index] |= . + $jsNew'`
			index=$((index + 1))
		fi
	done
}

WriteStep()
{
	/bin/echo "${jsOut}" > ${SYNOPKG_TEMP_LOGFILE}
}

##
# @retval 1 if in cluster
# @retval 0 if not
#
NotInCluster()
{
	if [ "yes" = "`/bin/get_key_value /usr/syno/etc/ccc/cccinfo.conf runccc`" ]; then
		return 1
	fi
	return 0
}

##
# Check if is single host mode
# #retval  0   if is single host mode
# @retval  1   otherwise
#
IsSingleHostMode()
{
	grep "ETCD_LISTEN_PEER_URLS" "/usr/syno/etc/ccc/etcd.env" | grep -q "127.0.0.1"
}

##
# Check if any local vm running or any local repo is being used
# #retval  0   if at least one local vm running or local repo is using by other vm
# @retval  1   otherwise
#
IsLocalVMRunningOrLocalRepoUsing()
{
	if [ -x "${CCC_GUEST_TOOL}" ]; then
		${CCC_GUEST_TOOL} -s > /dev/null 2>&1
		if [ "$?" -eq 0 ]; then
			return 1
		else
			return 0
		fi
	fi
	return 1
}

Main()
{
	local NeedCheckMinor="true"
	local NeedCheckVM="true"
	local parameters=""

	if ! synopkg status Virtualization; then
		NeedCheckVM="false"
	fi
	if NotInCluster; then
		NeedCheckMinor="false"
		NeedCheckVM="false"
	fi

	if [ "${NeedCheckMinor}" = "true" ]; then
		if ! IsSingleHostMode; then
			parameters+=" might_minor_other_host_desc"
		fi
	fi
	if [ "${NeedCheckVM}" = "true" ]; then
		if IsLocalVMRunningOrLocalRepoUsing; then
			parameters+=" local_vm_running_or_local_storage_using_desc"
		fi
	fi

	AppendStepArray ${parameters}
	WriteStep
}

Main
exit 0
