#!/bin/sh
# Copyright (c) 2018 Synology Inc. All rights reserved.

UNINSTALL_VMM_TITLE="Disinstallare Virtual Machine Manager"
CONFIRM_UNINSTALL_LABEL="Conferma disinstallazione"
EXIST_DATA_SUGGEST_DESC="La disinstallazione di Virtual Machine Manager non comporterà la rimozione dei dischi virtuali e delle immagini. Per eliminare i dati, ritornare al pacchetto per procedere.<br>Nota: la disinstallazione e la reinstallazione del pacchetto possono essere un metodo per risolvere gli errori di Virtual Machine Manager."
MIGHT_MINOR_OTHER_HOST_DESC="Questo Synology NAS fa parte di un cluster Virtual Machine Manager. Dopo la disinstallazione del pacchetto, l'host non si troverà più nel cluster originale, ma sarà mostrato solo come offline. Il cluster si bloccherà quando online sono presenti meno della metà dei suoi host."
LOCAL_VM_RUNNING_OR_LOCAL_STORAGE_USING_DESC="Sono ancora presenti macchine virtuali in esecuzione. La disinstallazione sarà sospesa per 5 minuti per lo spegnimento delle macchine virtuali; in alternativa, successivamente sarà eseguito l'arresto forzato."
CCC_GUEST_TOOL="/var/packages/Virtualization/target/bin/synocccguest"

jsOut="[{
	\"step_title\": \"${UNINSTALL_VMM_TITLE}\",
	\"items\": [{
		\"type\": \"multiselect\",
		\"desc\": \"${EXIST_DATA_SUGGEST_DESC}\",
		\"subitems\": []
	}]
}]"
index=1

AppendStepArray()
{
	for item in $@
	do
		jsNew=""
		case $item in
			"might_minor_other_host_desc")
				jsNew="{
						\"step_title\": \"${UNINSTALL_VMM_TITLE}\",
						\"invalid_next_disabled\": true,
						\"items\": [{
							\"type\": \"multiselect\",
							\"desc\": \"${MIGHT_MINOR_OTHER_HOST_DESC}\",
							\"subitems\": [{
								\"desc\": \"${CONFIRM_UNINSTALL_LABEL}\",
								\"validator\": {
									\"fn\": \"{return true === arguments[0];}\"
								}
							}]
						}]
					}"
				;;
			"local_vm_running_or_local_storage_using_desc")
				jsNew="{
						\"step_title\": \"${UNINSTALL_VMM_TITLE}\",
						\"invalid_next_disabled\": true,
						\"items\": [{
							\"type\": \"multiselect\",
							\"desc\": \"${LOCAL_VM_RUNNING_OR_LOCAL_STORAGE_USING_DESC}\",
							\"subitems\": [{
								\"desc\": \"${CONFIRM_UNINSTALL_LABEL}\",
								\"validator\": {
									\"fn\": \"{return true === arguments[0];}\"
								}
							}]
						}]
					}"
				;;
			*)
				echo "Unknown parameter ${item}"
				;;
		esac
		if [ -n "$jsNew" ]; then
			jsOut=`/bin/echo "${jsOut}" | jq --argjson jsNew "${jsNew}" --argjson index "${index}" '.[$index] |= . + $jsNew'`
			index=$((index + 1))
		fi
	done
}

WriteStep()
{
	/bin/echo "${jsOut}" > ${SYNOPKG_TEMP_LOGFILE}
}

##
# @retval 1 if in cluster
# @retval 0 if not
#
NotInCluster()
{
	if [ "yes" = "`/bin/get_key_value /usr/syno/etc/ccc/cccinfo.conf runccc`" ]; then
		return 1
	fi
	return 0
}

##
# Check if is single host mode
# #retval  0   if is single host mode
# @retval  1   otherwise
#
IsSingleHostMode()
{
	grep "ETCD_LISTEN_PEER_URLS" "/usr/syno/etc/ccc/etcd.env" | grep -q "127.0.0.1"
}

##
# Check if any local vm running or any local repo is being used
# #retval  0   if at least one local vm running or local repo is using by other vm
# @retval  1   otherwise
#
IsLocalVMRunningOrLocalRepoUsing()
{
	if [ -x "${CCC_GUEST_TOOL}" ]; then
		${CCC_GUEST_TOOL} -s > /dev/null 2>&1
		if [ "$?" -eq 0 ]; then
			return 1
		else
			return 0
		fi
	fi
	return 1
}

Main()
{
	local NeedCheckMinor="true"
	local NeedCheckVM="true"
	local parameters=""

	if ! synopkg status Virtualization; then
		NeedCheckVM="false"
	fi
	if NotInCluster; then
		NeedCheckMinor="false"
		NeedCheckVM="false"
	fi

	if [ "${NeedCheckMinor}" = "true" ]; then
		if ! IsSingleHostMode; then
			parameters+=" might_minor_other_host_desc"
		fi
	fi
	if [ "${NeedCheckVM}" = "true" ]; then
		if IsLocalVMRunningOrLocalRepoUsing; then
			parameters+=" local_vm_running_or_local_storage_using_desc"
		fi
	fi

	AppendStepArray ${parameters}
	WriteStep
}

Main
exit 0
