#!/bin/sh
# Copyright (c) 2018 Synology Inc. All rights reserved.

UNINSTALL_VMM_TITLE="Virtual Machine Manager 제거"
CONFIRM_UNINSTALL_LABEL="제거 확인"
EXIST_DATA_SUGGEST_DESC="Virtual Machine Manager를 제거해도 가상 디스크와 이미지는 제거되지 않습니다. 데이터를 삭제하려면 패키지로 돌아가 데이터를 삭제하십시오.<br>참고: 패키지를 제거하고 다시 설치하면 Virtual Machine Manager 오류가 해결될 수 있습니다."
MIGHT_MINOR_OTHER_HOST_DESC="이 Synology NAS는 Virtual Machine Manager 클러스터의 일부입니다. 패키지가 제거되면 호스트는 더 이상 원래 클러스터에 있지 않고 오프라인 상태로만 표시됩니다. 클러스터 호스트의 절반 이하가 온라인 상태이면 클러스터는 작동 중지됩니다."
LOCAL_VM_RUNNING_OR_LOCAL_STORAGE_USING_DESC="여전히 가상 컴퓨터가 실행되고 있습니다. 가상 컴퓨터가 종료되는 최대 5분 동안 제거가 일시 중단되거나 가상 컴퓨터가 5분 후에 강제 종료됩니다."
CCC_GUEST_TOOL="/var/packages/Virtualization/target/bin/synocccguest"

jsOut="[{
	\"step_title\": \"${UNINSTALL_VMM_TITLE}\",
	\"items\": [{
		\"type\": \"multiselect\",
		\"desc\": \"${EXIST_DATA_SUGGEST_DESC}\",
		\"subitems\": []
	}]
}]"
index=1

AppendStepArray()
{
	for item in $@
	do
		jsNew=""
		case $item in
			"might_minor_other_host_desc")
				jsNew="{
						\"step_title\": \"${UNINSTALL_VMM_TITLE}\",
						\"invalid_next_disabled\": true,
						\"items\": [{
							\"type\": \"multiselect\",
							\"desc\": \"${MIGHT_MINOR_OTHER_HOST_DESC}\",
							\"subitems\": [{
								\"desc\": \"${CONFIRM_UNINSTALL_LABEL}\",
								\"validator\": {
									\"fn\": \"{return true === arguments[0];}\"
								}
							}]
						}]
					}"
				;;
			"local_vm_running_or_local_storage_using_desc")
				jsNew="{
						\"step_title\": \"${UNINSTALL_VMM_TITLE}\",
						\"invalid_next_disabled\": true,
						\"items\": [{
							\"type\": \"multiselect\",
							\"desc\": \"${LOCAL_VM_RUNNING_OR_LOCAL_STORAGE_USING_DESC}\",
							\"subitems\": [{
								\"desc\": \"${CONFIRM_UNINSTALL_LABEL}\",
								\"validator\": {
									\"fn\": \"{return true === arguments[0];}\"
								}
							}]
						}]
					}"
				;;
			*)
				echo "Unknown parameter ${item}"
				;;
		esac
		if [ -n "$jsNew" ]; then
			jsOut=`/bin/echo "${jsOut}" | jq --argjson jsNew "${jsNew}" --argjson index "${index}" '.[$index] |= . + $jsNew'`
			index=$((index + 1))
		fi
	done
}

WriteStep()
{
	/bin/echo "${jsOut}" > ${SYNOPKG_TEMP_LOGFILE}
}

##
# @retval 1 if in cluster
# @retval 0 if not
#
NotInCluster()
{
	if [ "yes" = "`/bin/get_key_value /usr/syno/etc/ccc/cccinfo.conf runccc`" ]; then
		return 1
	fi
	return 0
}

##
# Check if is single host mode
# #retval  0   if is single host mode
# @retval  1   otherwise
#
IsSingleHostMode()
{
	grep "ETCD_LISTEN_PEER_URLS" "/usr/syno/etc/ccc/etcd.env" | grep -q "127.0.0.1"
}

##
# Check if any local vm running or any local repo is being used
# #retval  0   if at least one local vm running or local repo is using by other vm
# @retval  1   otherwise
#
IsLocalVMRunningOrLocalRepoUsing()
{
	if [ -x "${CCC_GUEST_TOOL}" ]; then
		${CCC_GUEST_TOOL} -s > /dev/null 2>&1
		if [ "$?" -eq 0 ]; then
			return 1
		else
			return 0
		fi
	fi
	return 1
}

Main()
{
	local NeedCheckMinor="true"
	local NeedCheckVM="true"
	local parameters=""

	if ! synopkg status Virtualization; then
		NeedCheckVM="false"
	fi
	if NotInCluster; then
		NeedCheckMinor="false"
		NeedCheckVM="false"
	fi

	if [ "${NeedCheckMinor}" = "true" ]; then
		if ! IsSingleHostMode; then
			parameters+=" might_minor_other_host_desc"
		fi
	fi
	if [ "${NeedCheckVM}" = "true" ]; then
		if IsLocalVMRunningOrLocalRepoUsing; then
			parameters+=" local_vm_running_or_local_storage_using_desc"
		fi
	fi

	AppendStepArray ${parameters}
	WriteStep
}

Main
exit 0
