#!/bin/sh
# Copyright (c) 2016 Synology Inc. All rights reserved.

PKG_TAG="VirtualMachineManager"
PKG_LEAST_API_COMPATIBLE_VERSION="2.5.0-9421"
PKG_LEAST_LOCAL_VM_RUNNING_VERSION="2.4.0-9207"
API_INCOMPATIBLE_WARNING_TITLE="執行不相容升級"
API_INCOMPATIBLE_WARNING_DESC="執行套件不相容升級時，在所有主機皆完成升級之前，叢集將暫時無法使用。且升級期間，虛擬機器只允許在本地端運行。若要執行升級，請勾選下方核取方塊來確認。"
DISALLOW_LOCAL_VM_RUNNING_WARNING_TITLE="虛擬機器在升級期間無法運行"
DISALLOW_LOCAL_VM_RUNNING_WARNING_DESC="升級套件時，必須關閉符合以下任一條件的虛擬機器：<br>1. 虛擬機器的儲存空間在此台主機上。<br>2. 虛擬機器在此台主機上運行。"
INCOMPATIBLE_WITH_NO_VM_RUNNING_WARNING_TITLE="執行不相容升級"
INCOMPATIBLE_WITH_NO_VM_RUNNING_WARNING_DESC="執行套件不相容升級時，在所有主機皆完成升級之前，叢集將暫時無法使用。且升級期間，所有虛擬機器必須關機。若要執行升級，請勾選下方核取方塊來確認。"
CONFIRM_UPGRADE_LABEL="確認升級"
LICENSE_WARNING_TITLE="更新後需要授權"
LICENSE_VDSM_WARNING_DESC="更新至此版本後，每台 Synology NAS 將會得到一組免費的 Virtual DSM 授權。超過授權數量的 Virtual DSM 將無法開機。"
LICENSE_PRO_WARNING_DESC="更新至此版本後，需要 VMM 專業版授權才能啟用進階功能。若更新後叢集中無可用授權，所有專業版功能將停用。"
CCC_PKG_TOOL="/var/packages/Virtualization/target/bin/synoccctool"

ProduceEmptyArray()
{
	/bin/cat > ${SYNOPKG_TEMP_LOGFILE} <<EOF
[]
EOF
}

ProduceStepArray()
{
	local jsOut="[]"
	local jsVDSMLicense="{}"
	local jsProLicense="{}"
	local jsApiIncompatible="{}"
	local jsDisallowLocalGuestRunning="{}"
	local jsIncompatibleWithNoGuestRunning="{}"
	local index=0
	local _DISALLOW_LOCAL_VM_RUNNING_WARNING_DESC=""
	local _API_INCOMPATIBLE_WARNING_DESC=""
	local _INCOMPATIBLE_WITH_NO_VM_RUNNING_WARNING_DESC=""
	local _SHOW_VDSM_LICENSE=0
	local _SHOW_PRO_LICENSE=0

	for item in $@
	do
		if [ $item = "disallow_local_vm_running" ]; then
			_DISALLOW_LOCAL_VM_RUNNING_WARNING_DESC=${DISALLOW_LOCAL_VM_RUNNING_WARNING_DESC}
		fi
		if [ $item = "api_incompataible_upgrade_desc" ]; then
			_API_INCOMPATIBLE_WARNING_DESC=${API_INCOMPATIBLE_WARNING_DESC}
		fi
		if [ $item = "vdsm_license" ]; then
			_SHOW_VDSM_LICENSE=1
		fi
		if [ $item = "pro_license" ]; then
			_SHOW_PRO_LICENSE=1
		fi
	done
	if [ "${_DISALLOW_LOCAL_VM_RUNNING_WARNING_DESC}" != "" ] && [ "${_API_INCOMPATIBLE_WARNING_DESC}" != "" ]; then
		_DISALLOW_LOCAL_VM_RUNNING_WARNING_DESC=""
		_API_INCOMPATIBLE_WARNING_DESC=""
		_INCOMPATIBLE_WITH_NO_VM_RUNNING_WARNING_DESC=${INCOMPATIBLE_WITH_NO_VM_RUNNING_WARNING_DESC}
	fi

	jsVDSMLicense="{
			\"step_title\": \"${LICENSE_WARNING_TITLE}\",
			\"invalid_next_disabled\": true,
			\"items\": [{
				\"type\": \"multiselect\",
				\"desc\": \"${LICENSE_VDSM_WARNING_DESC}\",
				\"subitems\": [{
					\"desc\": \"${CONFIRM_UPGRADE_LABEL}\",
					\"validator\": {
						\"fn\": \"{return true === arguments[0];}\"
					}
				}]
			}]
		}"

	jsProLicense="{
			\"step_title\": \"${LICENSE_WARNING_TITLE}\",
			\"invalid_next_disabled\": true,
			\"items\": [{
				\"type\": \"multiselect\",
				\"desc\": \"${LICENSE_PRO_WARNING_DESC}\",
				\"subitems\": [{
					\"desc\": \"${CONFIRM_UPGRADE_LABEL}\",
					\"validator\": {
						\"fn\": \"{return true === arguments[0];}\"
					}
				}]
			}]
		}"

	jsApiIncompatible="{
			\"step_title\": \"${API_INCOMPATIBLE_WARNING_TITLE}\",
			\"invalid_next_disabled\": true,
			\"items\": [{
				\"type\": \"multiselect\",
				\"desc\": \"${_API_INCOMPATIBLE_WARNING_DESC}\",
				\"subitems\": [{
					\"desc\": \"${CONFIRM_UPGRADE_LABEL}\",
					\"validator\": {
						\"fn\": \"{return true === arguments[0];}\"
					}
				}]
			}]
		}"

	jsDisallowLocalGuestRunning="{
			\"step_title\": \"${DISALLOW_LOCAL_VM_RUNNING_WARNING_TITLE}\",
			\"invalid_next_disabled\": true,
			\"items\": [{
				\"type\": \"multiselect\",
				\"desc\": \"${_DISALLOW_LOCAL_VM_RUNNING_WARNING_DESC}\",
				\"subitems\": [{
					\"desc\": \"${CONFIRM_UPGRADE_LABEL}\",
					\"validator\": {
						\"fn\": \"{return true === arguments[0];}\"
					}
				}]
			}]
		}"
	
	jsIncompatibleWithNoGuestRunning="{
			\"step_title\": \"${INCOMPATIBLE_WITH_NO_VM_RUNNING_WARNING_TITLE}\",
			\"invalid_next_disabled\": true,
			\"items\": [{
				\"type\": \"multiselect\",
				\"desc\": \"${_INCOMPATIBLE_WITH_NO_VM_RUNNING_WARNING_DESC}\",
				\"subitems\": [{
					\"desc\": \"${CONFIRM_UPGRADE_LABEL}\",
					\"validator\": {
						\"fn\": \"{return true === arguments[0];}\"
					}
				}]
			}]
		}"


	if [ "${_SHOW_VDSM_LICENSE}" -eq 1 ]; then
		jsOut=`/bin/cho "${jsOut}" | jq --argjson jsVDSMLicense "${jsVDSMLicense}" --argjson index "${index}" '.[$index] |= . + $jsVDSMLicense'`
		index=$((index + 1))
	fi
	if [ "${_SHOW_PRO_LICENSE}" -eq 1 ]; then
		jsOut=`/bin/echo "${jsOut}" | jq --argjson jsProLicense "${jsProLicense}" --argjson index "${index}" '.[$index] |= . + $jsProLicense'`
		index=$((index + 1))
	fi
	if [ "${_DISALLOW_LOCAL_VM_RUNNING_WARNING_DESC}" != "" ]; then
		jsOut=`/bin/echo "${jsOut}" | jq --argjson jsDisallowLocalGuestRunning "${jsDisallowLocalGuestRunning}" --argjson index "${index}" '.[$index] |= . + $jsDisallowLocalGuestRunning'`
		index=$((index + 1))
	fi
	if [ "${_API_INCOMPATIBLE_WARNING_DESC}" != "" ]; then
		jsOut=`/bin/echo "${jsOut}" | jq --argjson jsApiIncompatible "${jsApiIncompatible}" --argjson index "${index}" '.[$index] |= . + $jsApiIncompatible'`
		index=$((index + 1))
	fi
	if [ "${_INCOMPATIBLE_WITH_NO_VM_RUNNING_WARNING_DESC}" != "" ]; then
		jsOut=`/bin/echo "${jsOut}" | jq --argjson jsIncompatibleWithNoGuestRunning "${jsIncompatibleWithNoGuestRunning}" --argjson index "${index}" '.[$index] |= . + $jsIncompatibleWithNoGuestRunning'`
		index=$((index + 1))
	fi

	/bin/echo "${jsOut}" > ${SYNOPKG_TEMP_LOGFILE}
}

##
# @retval 1 if in cluster
# @retval 0 if not
#
NotInCluster()
{
	if [ "yes" = "`/bin/get_key_value /usr/syno/etc/ccc/cccinfo.conf runccc`" ]; then
		return 1
	fi
	return 0
}

##
# Check if this is an api incompatible upgrade
# @retval  2   is api incompatible upgrade
# @retval  1   unknown error
# #retval  0   is compatible upgrade
#
CheckPackageAPIIncompatibleUpgrade()
{
	local old_version="${SYNOPKG_OLD_PKGVER}"
	local old_buildnum=`echo ${old_version} | awk -F"-" '{print $2}'`
	local compat_version=${PKG_LEAST_API_COMPATIBLE_VERSION}
	local compat_buildnum=`echo ${compat_version} | awk -F"-" '{print $2}'`

	if [ -z "${old_buildnum}" ] || [ -z "${compat_buildnum}" ]; then
		logger -p err -t "${PKG_TAG}" "Failed to acquire old version:\"${old_buildnum}\" or API compatible version:\"${compat_version}\""
		return 1
	fi

	logger -p err -t "${PKG_TAG}" "(old_ver,compat_ver)=(${old_version},${compat_version})"

	if [ "${old_buildnum}" -lt "${compat_buildnum}" ]; then
		logger -p err -t "${PKG_TAG}" "Need api incompatible upgrade"
		return 2
	fi
	return 0
}

##
# Check if this is an allow-local-VM-running upgrade
# @retval  2   disallow VM running during upgrade
# @retval  1   unknown error
# #retval  0   is compatible upgrade
#
CheckAllowLocalVMRunning()
{
	local old_version="${SYNOPKG_OLD_PKGVER}"
	local old_buildnum=`echo ${old_version} | awk -F"-" '{print $2}'`
	local compat_version=${PKG_LEAST_LOCAL_VM_RUNNING_VERSION}
	local compat_buildnum=`echo ${compat_version} | awk -F"-" '{print $2}'`

	if [ -z "${old_buildnum}" ] || [ -z "${compat_buildnum}" ]; then
		logger -p err -t "${PKG_TAG}" "Failed to acquire old version:\"${old_buildnum}\" or allow-VM-running version:\"${compat_version}\""
		return 1
	fi

	logger -p err -t "${PKG_TAG}" "(old_ver,compat_ver)=(${old_version},${compat_version})"

	if [ "${old_buildnum}" -lt "${compat_buildnum}" ]; then
		logger -p err -t "${PKG_TAG}" "Need upgrade with all local guest shutdown."
		return 2
	fi
	return 0
}

IsNeedShowVDSMLicenseStep()
{
	local old_version="${SYNOPKG_OLD_PKGVER}"
	local old_buildnum=`echo ${old_version} | awk -F"-" '{print $2}'`
	local VDSM_LICENSE_VERSION="8416"

	if [ -z "${old_buildnum}" ]; then
		logger -p err -t "${PKG_TAG}" "Failed to acquire old version:\"${old_buildnum}\""
		return 1
	fi

	if [ "${old_buildnum}" -lt "${VDSM_LICENSE_VERSION}" ]; then
		return 1
	fi

	return 0
}

IsNeedShowProLicenseStep()
{
	local old_version="${SYNOPKG_OLD_PKGVER}"
	local old_buildnum=`echo ${old_version} | awk -F"-" '{print $2}'`
	local PRO_LICENSE_VERSION="8927"

	if [ -z "${old_buildnum}" ]; then
		logger -p err -t "${PKG_TAG}" "Failed to acquire old version:\"${old_buildnum}\""
		return 1
	fi

	if [ "${old_buildnum}" -lt "${PRO_LICENSE_VERSION}" ]; then
		return 1
	fi

	return 0
}

IsSingleNodeCluster()
{
	if [ -x "${CCC_PKG_TOOL}" ]; then
		${CCC_PKG_TOOL} --cluster-size
		local CLUSTER_SIZE="$?"
		logger -p err -t "${PKG_TAG}" "synoccctool return cluster size: ${CLUSTER_SIZE}"

		if [ 1 -eq "${CLUSTER_SIZE}" ]; then
			return 1
		fi
	fi

	return 0
}

# check host is in cluster and exit if not
if NotInCluster; then
	logger -p err -t "${PKG_TAG}" "Not in cluster, no need to check incompatible upgrade"
	ProduceEmptyArray
	exit 0
fi

CheckPackageAPIIncompatibleUpgrade
IsAPIIncompatibleUpgrade="$?"
CheckAllowLocalVMRunning
blAllowLocalVMRunning="$?"
IsNeedShowVDSMLicenseStep
blShowVDSMLicenseStep="$?"
IsNeedShowProLicenseStep
blShowProLicenseStep="$?"
parameters=""
if [ "${blAllowLocalVMRunning}" -eq "2" ]; then
	parameters+=" disallow_local_vm_running"
fi
if [ "${IsAPIIncompatibleUpgrade}" -eq "2" ] && IsSingleNodeCluster; then
	parameters+=" api_incompataible_upgrade_desc"
fi
if [ "${blShowVDSMLicenseStep}" -eq "1" ]; then
	parameters+=" vdsm_license"
fi
if [ "${blShowProLicenseStep}" -eq "1" ]; then
	parameters+=" pro_license"
fi


ProduceStepArray ${parameters}
exit 0
