#!/bin/sh

#note: hard-code for these path, you need to specify if you wanna use by another package
PACKAGE_BASE_PATH="/var/packages/Virtualization"
ETC_DIR=${PACKAGE_BASE_PATH}"/etc"
DSM60_DB="/usr/syno/etc/synobtrfsreplica/snap_replica.db"
REPLICA_DB=${ETC_DIR}"/snap_replica.db"
INIT_SQL="${PACKAGE_BASE_PATH}/target/btrfsreplica_sql/init_db.sql"
DB_VER="1"

init_db()
{
	if [ ! -f ${INIT_SQL} ]; then
		logger -p user.info -t synobtrfsreplica_db "Failed to init snap_replica.db since ${INIT_SQL} is not existed"
	else
		sqlite3 ${REPLICA_DB} < ${INIT_SQL}
		logger -p user.info -t synobtrfsreplica_db "Init synodrnode.db done"
	fi
}

start()
{
	logger -p user.info -t synobtrfsreplica_db " ---> Start DB Check"

	if [ ! -f "${REPLICA_DB}" ]; then
		init_db
	else
		local existed=`sqlite3 ${REPLICA_DB} "SELECT 1 FROM sqlite_master WHERE type='table' AND name='db_ver';"`

		if [ -z "$existed" ]; then
			init_db
		else
			local ver=`sqlite3 ${REPLICA_DB} "SELECT value FROM db_ver;"`;
			if [ -z "$ver" -o "$DB_VER" != "${ver}" ]; then
				init_db
			fi
		fi

	fi
	logger -p user.info -t synobtrfsreplica_db " <--- Finish DRNode Check"
	/sbin/initctl emit syno.btrfs.replica.ready
}

migrate_from_DSM60_beta1()
{
	BETA1_CONFIG="/usr/syno/etc/share_replica/share_replica.db"
	SHARE_REPLICA_BIN=${PACKAGE_BASE_PATH}"/target/sbin/synosharereplica"

	if [ -e "${BETA1_CONFIG}" ];then
		if [ -e "${SHARE_REPLICA_BIN}" ];then
			${SHARE_REPLICA_BIN} --replica_updater
			RET=$?
			if [ "${RET}" -eq "0" ]; then
				rm -f "${BETA1_CONFIG}"
				rm -rf /usr/syno/etc/share_replica
			else
				mv "${BETA1_CONFIG}" "${BETA1_CONFIG}.failed"
			fi
		fi
	fi
}

migrate_from_DSM60_rc()
{
	if [ ! -e "${REPLICA_DB}" ];then
		if	[ -e ${DSM60_DB} ];then
			cp "${DSM60_DB}" "${REPLICA_DB}"
			if	[ $? -ne 0	]; then
				logger -p user.error -t synobtrfsreplica_db "Failed to mirgate btrfs replica from DSM6-0"
				return
			fi
			mv "${DSM60_DB}" "${DSM60_DB}.dsm60"
		fi
	fi
	logger -p user.info -t synobtrfsreplica_db " <--- Finish migrate from DSM6-0"
}

case "$1" in
start)
	migrate_from_DSM60_beta1
	migrate_from_DSM60_rc
	start
;;
*)
	echo "usage: $0 [start]" >&2
	exit 1
;;
esac
