#!/bin/sh

OUTPUT_DIR="$1"
VIRSH=/usr/local/bin/virsh
PKGETC=/var/packages/Virtualization/etc

Init()
{
	# output directory is missing
	if [ -z "${OUTPUT_DIR}" ]; then
		return
	fi
	mkdir -p ${OUTPUT_DIR}
}

GetCluster()
{
	local SYNOETCD=/usr/local/bin/synoetcd
	local ETCDCTL=/usr/local/bin/etcdctl

	${SYNOETCD} dump \
		| grep -v /syno/live_cluster/cluster_controller/libvirtd_auth_pass \
		| grep -v /syno/live_cluster/cluster_controller/libvirtd_auth_user \
		| grep -v /syno/live_cluster/host/.*/session \
			&> ${OUTPUT_DIR}/dashboard.dump
	${ETCDCTL} member list &> ${OUTPUT_DIR}/etcdctl.member.list
	${ETCDCTL} cluster-health &> ${OUTPUT_DIR}/etcdctl.cluster.health
}

GetGuest()
{
	${VIRSH} list &> ${OUTPUT_DIR}/virsh.list
	if [ "0" -eq "$?" ]; then
		mkdir -p ${OUTPUT_DIR}/vdsm.xml
		for i in $(cat ${OUTPUT_DIR}/virsh.list | tail -n +3 | awk '{print $2}'); do
			${VIRSH} dumpxml $i > ${OUTPUT_DIR}/vdsm.xml/$i
		done
	fi
}

GetNet()
{
	local OVSVSCTL=/bin/ovs-vsctl

	${OVSVSCTL} show &> ${OUTPUT_DIR}/ovs-vsctl.show
	ls -d /sys/class/net/eth*/device/virtfn* > ${OUTPUT_DIR}/sys.class.virtfn
	${VIRSH} net-list &> ${OUTPUT_DIR}/virsh.net-list
	if [ "0" -eq "$?" ]; then
		mkdir -p ${OUTPUT_DIR}/net.xml
		for i in $(cat ${OUTPUT_DIR}/virsh.net-list | tail -n +3 | awk '{print $1}'); do
			${VIRSH} net-dumpxml $i > ${OUTPUT_DIR}/net.xml/$i
		done
	fi
}

GetDisk()
{
	synoiscsiwebapi lun list &> ${OUTPUT_DIR}/lun.dump
	for item in /volume*/@Repository /volume*/vdsm_repo.conf; do
		if [ -e "${item}" ]; then
			DEST_DIR="${OUTPUT_DIR}"`/usr/bin/dirname "${item}"`
			mkdir -p "${DEST_DIR}"
			cp -rsx "${item}" "${DEST_DIR}"
		fi
	done
}

GetClusterLog()
{
	local CCCTOOL=/var/packages/Virtualization/target/bin/synoccctool

	${CCCTOOL} --log-export 0 1000 0 1 0 &> ${OUTPUT_DIR}/log.dump
}

GetSnapshot()
{
	local GUESTSNAP_OUTPUT="${OUTPUT_DIR}/local_snapshots"
	local DRGROUPDIR=${PKGETC}/drgroup
	local DRGROUPTOOL=/var/packages/Virtualization/target/sbin/synodrgsnap
	local GUESTSNAPTOOL=/var/packages/Virtualization/target/bin/synoccc_gsnap

	mkdir -p ${GUESTSNAP_OUTPUT}
	if [ -d ${DRGROUPDIR} ]; then
		for guest_id in `ls ${DRGROUPDIR}`; do
			GSNAP_OUTPUT="${GUESTSNAP_OUTPUT}/${guest_id}"
			mkdir -p ${GSNAP_OUTPUT}
			if [ -x ${DRGROUPTOOL} ]; then
				${DRGROUPTOOL} l ${guest_id} &> ${GSNAP_OUTPUT}/synodrgsnap.list
				${DRGROUPTOOL} status ${guest_id} &> ${GSNAP_OUTPUT}/synodrgsnap_status.dump
			fi
			if [ -x ${GUESTSNAPTOOL} ]; then
				${GUESTSNAPTOOL} l ${guest_id} &> ${GSNAP_OUTPUT}/guestsnap.list
			fi
			/usr/syno/bin/synowebapi --exec api=SYNO.CCC.GuestSnap method=list access_key=\"${guest_id}\" keyType=0 additional=[\"guest_disks\",\"guest_nics\"] &> ${GSNAP_OUTPUT}/guestsnap_detail.list
		done
	fi
	/usr/syno/bin/synowebapi --exec api=SYNO.Virtualization.GuestProtect.Snap method=list_all version=1 &> ${OUTPUT_DIR}/guestsnap.list
}

GetSnapshotPolicy()
{
	local GSNAPPOLICY_OUTPUT="${OUTPUT_DIR}/local_gsnap_policies"
	local GSNAPPOLICYDIR=${PKGETC}/gsnap_policy
	local GSNAPPOLICYTOOL=/var/packages/Virtualization/target/bin/synoccc_gsnappolicy

	if [ -d ${GSNAPPOLICYDIR} ]; then
		cp -r ${GSNAPPOLICYDIR} ${GSNAPPOLICY_OUTPUT}/
		/usr/syno/bin/synoschedtask --get > ${GSNAPPOLICY_OUTPUT}/local_schedtask.dump
	fi
	if [ -x ${GSNAPPOLICYTOOL} ]; then
		${GSNAPPOLICYTOOL} l sched &> ${OUTPUT_DIR}/gsnap_policy_sched.list
		${GSNAPPOLICYTOOL} l retent &> ${OUTPUT_DIR}/gsnap_policy_retent.list
	fi
}

GetLogWhiteList()
{
	local LOG_WHITELIST_SCRIPT=/usr/syno/bin/collector_package_whitelist.sh
	local LOG_WHITELIST=/var/packages/Virtualization/scripts/log_whitelist
	local DEST_DIR=""

	if [ ! -e "${LOG_WHITELIST_SCRIPT}" ]; then
		# file in log_whitelist are only automatically copied after DSM 6.2
		for item in `cat ${LOG_WHITELIST}`; do
			if [ -e "${item}" ]; then
				DEST_DIR="${OUTPUT_DIR}"`/usr/bin/dirname "${item}"`
				mkdir -p "${DEST_DIR}"
				cp -rsx "${item}" "${DEST_DIR}"
			fi
		done
	fi
}

Init
if [ "yes" = "`/bin/get_key_value /usr/syno/etc/ccc/cccinfo.conf runccc`" ]; then
	GetCluster
	GetGuest
	GetNet
	GetDisk
	GetClusterLog
	GetSnapshot
	GetSnapshotPolicy
fi
GetLogWhiteList
