"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.polyFillObjAssign = polyFillObjAssign;
exports.qemuName2KeyCode = qemuName2KeyCode;
exports.allKeyboardLayout = void 0;

var Log = _interopRequireWildcard(require("../../util/logging.js"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function polyFillObjAssign() {
  if (typeof Object.assign === 'function') {
    return;
  }

  Object.defineProperty(Object, "assign", {
    value: function assign(target, varArgs) {
      'use strict';

      if (target == null) {
        throw new TypeError('Cannot convert undefined or null to object');
      }

      var to = Object(target);

      for (var index = 1; index < arguments.length; index++) {
        var nextSource = arguments[index];

        if (nextSource != null) {
          for (var nextKey in nextSource) {
            if (Object.prototype.hasOwnProperty.call(nextSource, nextKey)) {
              to[nextKey] = nextSource[nextKey];
            }
          }
        }
      }

      return to;
    }
  });
}

function qemuName2KeyCode(kb_layout, keysym_name, key_down_list) {
  if (!(kb_layout in allKeyboardLayout)) {
    Log.Error("Unable to find layout.", kb_layout);
    return;
  }

  if ('string' !== typeof keysym_name) {
    Log.Error("Bad keysym_name", keysym_name);
    return;
  } // old js do not have Object.assign


  polyFillObjAssign();
  var keycode_map = Object.assign({}, allKeyboardLayout.common, allKeyboardLayout[kb_layout]);
  var keycode_arr = null;

  if (keycode_map) {
    if (keysym_name in keycode_map) {
      keycode_arr = keycode_map[keysym_name];
    } else if (keysym_name.toLowerCase() in keycode_map) {
      keycode_arr = keycode_map[keysym_name.toLowerCase()];
    }
  }

  if (!(keycode_arr instanceof Array)) {
    Log.Error("Keysym not found in keycode_map");
    return;
  } // The keycode_arr could either be an array of keycode array (when the keysym has multiple keycode combinations) or a simple keycode array.
  // Ex: Both 0x28 + AltGr and 0x10 + shift can generate "@" in en-gb.


  if (!(keycode_arr[0] instanceof Array)) {
    return keycode_arr;
  } // We try to return possible keycode set with least modifiers.


  var shortest_possible_set = null;
  var cur_shift_down = false,
      cur_ctrl_down = false,
      cur_alt_down = false;

  if (key_down_list) {
    cur_shift_down = "ShiftLeft" in key_down_list || "ShiftRight" in key_down_list;
    cur_ctrl_down = "ControlLeft" in key_down_list || "ControlRight" in key_down_list;
    cur_alt_down = "AltLeft" in key_down_list || "AltRight" in key_down_list;
  }

  for (var i = keycode_arr.length - 1; 0 <= i; i--) {
    var has_shift = false;
    var has_ctrl = false;
    var has_alt = false;

    for (var j = 1; j < keycode_arr[i].length; j++) {
      switch (keycode_arr[i][j]) {
        case "shift":
          has_shift = true;
          break;

        case "altgr":
          has_alt = true;
          has_ctrl = true;
          break;

        case "ctrl":
          has_ctrl = true;
          break;

        default:
          break;
      }
    }

    if (cur_shift_down && !has_shift || cur_ctrl_down && !has_ctrl || cur_alt_down && !has_alt) {
      keycode_arr.splice(i, 1);
    } else if (!shortest_possible_set || shortest_possible_set.length > keycode_arr[i].length) {
      shortest_possible_set = keycode_arr[i];
    }
  }

  return shortest_possible_set;
}

;
const allKeyboardLayout = {
  "common": {
    "Shift_R": [0x36],
    "Shift_L": [0x2a],
    "Alt_R": [0xb8],
    "Mode_switch": [0xb8],
    "ISO_Level3_Shift": [0xb8],
    "Alt_L": [0x38],
    "Control_R": [0x9d],
    "Control_L": [0x1d],
    "Super_R": [0xdc],
    "Super_L": [0xdb],
    "Menu": [0xdd],
    "1": [0x2],
    "2": [0x3],
    "3": [0x4],
    "4": [0x5],
    "5": [0x6],
    "6": [0x7],
    "7": [0x8],
    "8": [0x9],
    "9": [0xa],
    "0": [0xb],
    "BackSpace": [0xe],
    "Tab": [0xf],
    "ISO_Left_Tab": [0xf, "shift"],
    "q": [0x10],
    "w": [0x11],
    "e": [0x12],
    "r": [0x13],
    "t": [0x14],
    "y": [0x15],
    "u": [0x16],
    "i": [0x17],
    "o": [0x18],
    "p": [0x19],
    "a": [0x1e],
    "s": [0x1f],
    "d": [0x20],
    "f": [0x21],
    "g": [0x22],
    "h": [0x23],
    "j": [0x24],
    "k": [0x25],
    "l": [0x26],
    "Return": [0x1c],
    "z": [0x2c],
    "x": [0x2d],
    "c": [0x2e],
    "v": [0x2f],
    "b": [0x30],
    "n": [0x31],
    "m": [0x32],
    "space": [0x39],
    "less": [0x56],
    "greater": [0x56, "shift"],
    "bar": [0x56, "altgr"],
    "brokenbar": [0x56, "shift", "altgr"],
    "Escape": [0x1],
    "F1": [0x3b],
    "F2": [0x3c],
    "F3": [0x3d],
    "F4": [0x3e],
    "F5": [0x3f],
    "F6": [0x40],
    "F7": [0x41],
    "F8": [0x42],
    "F9": [0x43],
    "F10": [0x44],
    "F11": [0x57],
    "F12": [0x58],
    "Print": [0xb7],
    "Sys_Req": [0xb7],
    "Execute": [0xb7],
    "Scroll_Lock": [0x46],
    "Insert": [0xd2],
    "Delete": [0xd3],
    "Home": [0xc7],
    "End": [0xcf],
    "Page_Up": [0xc9],
    "Page_Down": [0xd1],
    "Left": [0xcb],
    "Up": [0xc8],
    "Down": [0xd0],
    "Right": [0xcd],
    "Num_Lock": [0x45],
    "KP_Divide": [0xb5],
    "KP_Multiply": [0x37],
    "KP_Subtract": [0x4a],
    "KP_Add": [0x4e],
    "KP_Enter": [0x9c],
    "KP_Decimal": [0x53, "numlock"],
    "KP_Separator": [0x53, "numlock"],
    "KP_Delete": [0x53],
    "KP_0": [0x52, "numlock"],
    "KP_Insert": [0x52],
    "KP_1": [0x4f, "numlock"],
    "KP_End": [0x4f],
    "KP_2": [0x50, "numlock"],
    "KP_Down": [0x50],
    "KP_3": [0x51, "numlock"],
    "KP_Next": [0x51],
    "KP_4": [0x4b, "numlock"],
    "KP_Left": [0x4b],
    "KP_5": [0x4c, "numlock"],
    "KP_Begin": [0x4c],
    "KP_6": [0x4d, "numlock"],
    "KP_Right": [0x4d],
    "KP_7": [0x47, "numlock"],
    "KP_Home": [0x47],
    "KP_8": [0x48, "numlock"],
    "KP_Up": [0x48],
    "KP_9": [0x49, "numlock"],
    "KP_Prior": [0x49],
    "Caps_Lock": [0x3a]
  },
  "en-us": {
    // generated from XKB map us
    "exclam": [0x02, "shift"],
    "at": [0x03, "shift"],
    "numbersign": [0x04, "shift"],
    "dollar": [0x05, "shift"],
    "percent": [0x06, "shift"],
    "asciicircum": [0x07, "shift"],
    "ampersand": [0x08, "shift"],
    "asterisk": [0x09, "shift"],
    "parenleft": [0x0a, "shift"],
    "parenright": [0x0b, "shift"],
    "minus": [0x0c],
    "underscore": [0x0c, "shift"],
    "equal": [0x0d],
    "plus": [0x0d, "shift"],
    "bracketleft": [0x1a],
    "braceleft": [0x1a, "shift"],
    "bracketright": [0x1b],
    "braceright": [0x1b, "shift"],
    "semicolon": [0x27],
    "colon": [0x27, "shift"],
    "apostrophe": [0x28],
    "quotedbl": [0x28, "shift"],
    "grave": [0x29],
    "asciitilde": [0x29, "shift"],
    "backslash": [0x2b],
    "bar": [0x2b, "shift"],
    "comma": [0x33],
    "less": [0x33, "shift"],
    "period": [0x34],
    "greater": [0x34, "shift"],
    "slash": [0x35],
    "question": [0x35, "shift"]
  },
  "ar": {
    "map": [0x401],
    "exclam": [0x02, "shift"],
    "at": [0x03, "shift"],
    "numbersign": [0x04, "shift"],
    "dollar": [0x05, "shift"],
    "percent": [0x06, "shift"],
    "asciicircum": [0x07, "shift"],
    "ampersand": [0x08, "shift"],
    "asterisk": [0x09, "shift"],
    "parenleft": [0x0a, "shift"],
    "parenright": [0x0b, "shift"],
    "minus": [0x0c],
    "underscore": [0x0c, "shift"],
    "equal": [0x0d],
    "plus": [0x0d, "shift"],
    "Arabic_dad": [0x10, "altgr"],
    "Arabic_fatha": [0x10, "shift", "altgr"],
    "Arabic_sad": [0x11, "altgr"],
    "Arabic_fathatan": [0x11, "shift", "altgr"],
    "Arabic_theh": [0x12, "altgr"],
    "Arabic_damma": [0x12, "shift", "altgr"],
    "Arabic_qaf": [0x13, "altgr"],
    "Arabic_dammatan": [0x13, "shift", "altgr"],
    "Arabic_feh": [0x14, "altgr"],
    "UFEF9": [0x14, "shift", "altgr"],
    "Arabic_ghain": [0x15, "altgr"],
    "Arabic_hamzaunderalef": [0x15, "shift", "altgr"],
    "Arabic_ain": [0x16, "altgr"],
    "grave": [[0x16, "shift", "altgr"], [0x29]],
    "Arabic_ha": [0x17, "altgr"],
    "division": [0x17, "shift", "altgr"],
    "Arabic_khah": [0x18, "altgr"],
    "multiply": [0x18, "shift", "altgr"],
    "Arabic_hah": [0x19, "altgr"],
    "Arabic_semicolon": [0x19, "shift", "altgr"],
    "braceleft": [0x1a, "shift"],
    "Arabic_jeem": [0x1a, "altgr"],
    "braceright": [0x1b, "shift"],
    "Arabic_dal": [0x1b, "altgr"],
    "Arabic_sheen": [0x1e, "altgr"],
    "backslash": [[0x1e, "shift", "altgr"], [0x2b]],
    "Arabic_seen": [0x1f, "altgr"],
    "Arabic_yeh": [0x20, "altgr"],
    "bracketleft": [[0x20, "shift", "altgr"], [0x1a]],
    "Arabic_beh": [0x21, "altgr"],
    "bracketright": [[0x21, "shift", "altgr"], [0x1b]],
    "Arabic_lam": [0x22, "altgr"],
    "UFEF7": [0x22, "shift", "altgr"],
    "Arabic_alef": [0x23, "altgr"],
    "Arabic_hamzaonalef": [0x23, "shift", "altgr"],
    "Arabic_teh": [0x24, "altgr"],
    "Arabic_tatweel": [0x24, "shift", "altgr"],
    "Arabic_noon": [0x25, "altgr"],
    "Arabic_comma": [0x25, "shift", "altgr"],
    "Arabic_meem": [0x26, "altgr"],
    "slash": [[0x26, "shift", "altgr"], [0x35]],
    "semicolon": [0x27],
    "colon": [0x27, "shift"],
    "Arabic_kaf": [0x27, "altgr"],
    "quotedbl": [0x28, "shift"],
    "Arabic_tah": [0x28, "altgr"],
    "Arabic_thal": [0x29, "altgr"],
    "Arabic_shadda": [0x29, "shift", "altgr"],
    "bar": [0x2b, "shift"],
    "less": [[0x2b, "altgr"], [0x33, "shift"]],
    "greater": [[0x2b, "shift", "altgr"], [0x34, "shift"]],
    "Arabic_hamzaonyeh": [0x2c, "altgr"],
    "asciitilde": [[0x2c, "shift", "altgr"], [0x29, "shift"]],
    "Arabic_hamza": [0x2d, "altgr"],
    "Arabic_sukun": [0x2d, "shift", "altgr"],
    "Arabic_hamzaonwaw": [0x2e, "altgr"],
    "Arabic_kasra": [0x2e, "shift", "altgr"],
    "Arabic_ra": [0x2f, "altgr"],
    "Arabic_kasratan": [0x2f, "shift", "altgr"],
    "UFEFB": [0x30, "altgr"],
    "UFEF5": [0x30, "shift", "altgr"],
    "Arabic_alefmaksura": [0x31, "altgr"],
    "Arabic_maddaonalef": [0x31, "shift", "altgr"],
    "Arabic_tehmarbuta": [0x32, "altgr"],
    "apostrophe": [[0x32, "shift", "altgr"], [0x28]],
    "comma": [0x33],
    "Arabic_waw": [0x33, "altgr"],
    "period": [0x34],
    "Arabic_zain": [0x34, "altgr"],
    "question": [0x35, "shift"],
    "Arabic_zah": [0x35, "altgr"],
    "Arabic_question_mark": [0x35, "shift", "altgr"]
  },
  "bepo": {
    "dollar": [0x29],
    "numbersign": [0x29, "shift"],
    "U2013": [0x29, "altgr"],
    "U00b6": [0x29, "shift", "altgr"],
    "quotedbl": [0x2],
    "one": [0x2, "shift"],
    "U2014": [0x2, "altgr"],
    "U201e": [0x2, "shift", "altgr"],
    "guillemotleft": [0x3],
    "two": [0x3, "shift"],
    "less": [0x3, "altgr"],
    "U201c": [0x3, "shift", "altgr"],
    "guillemotright": [0x4],
    "three": [0x4, "shift"],
    "greater": [0x4, "altgr"],
    "U201d": [0x4, "shift", "altgr"],
    "parenleft": [0x5],
    "four": [0x5, "shift"],
    "bracketleft": [0x5, "altgr"],
    "U2264": [0x5, "shift", "altgr"],
    "parenright": [0x6],
    "five": [0x6, "shift"],
    "bracketright": [0x6, "altgr"],
    "U2265": [0x6, "shift", "altgr"],
    "at": [0x7],
    "six": [0x7, "shift"],
    "asciicircum": [0x7, "altgr"],
    "plus": [0x8],
    "seven": [0x8, "shift"],
    "U00b1": [0x8, "altgr"],
    "U00ac": [0x8, "shift", "altgr"],
    "minus": [0x9],
    "eight": [0x9, "shift"],
    "U2212": [0x9, "altgr"],
    "U00bc": [0x9, "shift", "altgr"],
    "slash": [0xa],
    "nine": [0xa, "shift"],
    "U00f7": [0xa, "altgr"],
    "U00bd": [0xa, "shift", "altgr"],
    "asterisk": [0xb],
    "zero": [0xb, "shift"],
    "U00d7": [0xb, "altgr"],
    "U00be": [0xb, "shift", "altgr"],
    "equal": [0xc],
    "U00b0": [0xc, "shift"],
    "U2260": [0xc, "altgr"],
    "U2032": [0xc, "shift", "altgr"],
    "percent": [0xd],
    "grave": [0xd, "shift"],
    "U2030": [0xd, "altgr"],
    "U2033": [0xd, "shift", "altgr"],
    "b": [0x10],
    "p": [0x12],
    "o": [0x13],
    "v": [0x16],
    "d": [0x17],
    "l": [0x18],
    "j": [0x19],
    "z": [0x1a],
    "w": [0x1b],
    "bar": [0x10, "altgr"],
    "brokenbar": [0x10, "shift", "altgr"],
    "eacute": [0x11],
    "Eacute": [0x11, "shift"],
    "dead_acute": [0x11, "altgr"],
    "ampersand": [0x12, "altgr"],
    "U00a7": [0x12, "shift", "altgr"],
    "U+0153": [0x13, "altgr"],
    "U+0152": [0x13, "shift", "altgr"],
    "egrave": [0x14],
    "Egrave": [0x14, "shift"],
    "dead_grave": [0x14, "altgr"],
    "dead_circumflex": [0x15],
    "exclam": [0x15, "shift"],
    "exclamdown": [0x15, "altgr"],
    "dead_caron": [0x16, "altgr"],
    "eth": [0x17, "altgr"],
    "ETH": [0x17, "shift", "altgr"],
    "U+0133": [0x19, "altgr"],
    "U+0132": [0x19, "shift", "altgr"],
    "U+0259": [0x1a, "altgr"],
    "U+018f": [0x1a, "shift", "altgr"],
    "a": [0x1e],
    "u": [0x1f],
    "i": [0x20],
    "e": [0x21],
    "c": [0x23],
    "t": [0x24],
    "s": [0x25],
    "r": [0x26],
    "n": [0x27],
    "m": [0x28],
    "ae": [0x1e, "altgr"],
    "AE": [0x1e, "shift", "altgr"],
    "ugrave": [0x1f, "altgr"],
    "Ugrave": [0x1f, "shift", "altgr"],
    "dead_diaeresis": [0x20, "altgr"],
    "U20ac": [0x21, "altgr"],
    "comma": [0x22],
    "semicolon": [0x22, "shift"],
    "U2019": [0x22, "altgr"],
    "U+031b": [0x22, "shift", "altgr"],
    "copyright": [0x23, "altgr"],
    "U017f": [0x23, "shift", "altgr"],
    "thorn": [0x24, "altgr"],
    "THORN": [0x24, "shift", "altgr"],
    "ssharp": [0x25, "altgr"],
    "U1e9e": [0x25, "shift", "altgr"],
    "registered": [0x26, "altgr"],
    "U2122": [0x26, "shift", "altgr"],
    "dead_tilde": [0x27, "altgr"],
    "masculine": [0x28, "shift", "altgr"],
    "ccedilla": [0x2b],
    "Ccedilla": [0x2b, "shift"],
    "dead_cedilla": [0x2b, "altgr"],
    "y": [0x2d],
    "x": [0x2e],
    "k": [0x30],
    "q": [0x32],
    "g": [0x33],
    "h": [0x34],
    "f": [0x35],
    "ecircumflex": [0x56],
    "Ecircumflex": [0x56, "shift"],
    "agrave": [0x2c],
    "Agrave": [0x2c, "shift"],
    "backslash": [0x2c, "altgr"],
    "braceleft": [0x2d, "altgr"],
    "U2018": [0x2d, "shift", "altgr"],
    "braceright": [0x2e, "altgr"],
    "period": [0x2f],
    "colon": [0x2f, "shift"],
    "U2026": [0x2f, "altgr"],
    "periodcentered": [0x2f, "shift", "altgr"],
    "asciitilde": [0x30, "altgr"],
    "U2328": [0x30, "shift", "altgr"],
    "apostrophe": [0x31],
    "question": [0x31, "shift"],
    "questiondown": [0x31, "altgr"],
    "U+0309": [0x31, "shift", "altgr"],
    "mu": [0x33, "altgr"],
    "U2020": [0x34, "altgr"],
    "U2021": [0x34, "shift", "altgr"],
    "ordfeminine": [0x35, "shift", "altgr"],
    "space": [0x39],
    "nobreakspace": [0x39, "shift"],
    "underscore": [0x39, "altgr"],
    "U202f": [0x39, "shift", "altgr"]
  },
  "cz": {
    "semicolon": [0x29],
    "dead_abovering": [0x29, "shift"],
    "plus": [0x2],
    "1": [0x2, "shift"],
    "ecaron": [0x3],
    "2": [0x3, "shift"],
    "scaron": [0x4],
    "3": [0x4, "shift"],
    "ccaron": [0x5],
    "4": [0x5, "shift"],
    "rcaron": [0x6],
    "5": [0x6, "shift"],
    "zcaron": [0x7],
    "6": [0x7, "shift"],
    "yacute": [0x8],
    "7": [0x8, "shift"],
    "aacute": [0x9],
    "8": [0x9, "shift"],
    "iacute": [0xa],
    "9": [0xa, "shift"],
    "eacute": [0xb],
    "0": [0xb, "shift"],
    "equal": [0x0c],
    "percent": [0x0c, "shift"],
    "dead_acute": [0x0d],
    "dead_caron": [0x0d, "shift"],
    "z": [0x15],
    "uacute": [0x1a],
    "slash": [0x1a, "shift"],
    "parenright": [0x1b],
    "parenleft": [0x1b, "shift"],
    "uring": [0x27],
    "quotedbl": [0x27, "shift"],
    "section": [0x28],
    "exclam": [0x28, "shift"],
    "dead_diaeresis": [0x2b],
    "apostrophe": [0x2b, "shift"],
    "backslash": [0x2b],
    "bar": [0x2b, "shift"],
    "y": [0x2c],
    "comma": [0x33],
    "question": [0x33, "shift"],
    "period": [0x34],
    "colon": [0x34, "shift"],
    "minus": [0x35],
    "underscore": [0x35, "shift"]
  },
  "da": {
    "map": [0x406],
    "exclam": [0x02, "shift"],
    "exclamdown": [0x02, "altgr"],
    "onesuperior": [0x02, "shift", "altgr"],
    "quotedbl": [0x03, "shift"],
    "at": [0x03, "altgr"],
    "twosuperior": [0x03, "shift", "altgr"],
    "numbersign": [0x04, "shift"],
    "sterling": [0x04, "altgr"],
    "threesuperior": [0x04, "shift", "altgr"],
    "currency": [0x05, "shift"],
    "dollar": [0x05, "altgr"],
    "onequarter": [0x05, "shift", "altgr"],
    "percent": [0x06, "shift"],
    "onehalf": [[0x06, "altgr"], [0x29]],
    "cent": [[0x06, "shift", "altgr"], [0x12, "shift", "altgr"]],
    "ampersand": [0x07, "shift"],
    "yen": [[0x07, "altgr"], [0x15, "shift", "altgr"]],
    "fiveeighths": [0x07, "shift", "altgr"],
    "slash": [0x08, "shift"],
    "braceleft": [0x08, "altgr"],
    "division": [0x08, "shift", "altgr"],
    "parenleft": [0x09, "shift"],
    "bracketleft": [0x09, "altgr"],
    "guillemotleft": [[0x09, "shift", "altgr"], [0x2c, "altgr"]],
    "parenright": [0x0a, "shift"],
    "bracketright": [0x0a, "altgr"],
    "guillemotright": [[0x0a, "shift", "altgr"], [0x2d, "altgr"]],
    "equal": [0x0b, "shift"],
    "braceright": [0x0b, "altgr"],
    "degree": [0x0b, "shift", "altgr"],
    "plus": [0x0c],
    "question": [0x0c, "shift"],
    "plusminus": [0x0c, "altgr"],
    "questiondown": [0x0c, "shift", "altgr"],
    "dead_acute": [0x0d],
    "dead_grave": [0x0d, "shift"],
    "bar": [0x0d, "altgr"],
    "brokenbar": [0x0d, "shift", "altgr"],
    "Greek_OMEGA": [0x10, "shift", "altgr"],
    "lstroke": [[0x11, "altgr"], [0x26, "altgr"]],
    "Lstroke": [[0x11, "shift", "altgr"], [0x26, "shift", "altgr"]],
    "EuroSign": [0x12, "altgr"],
    "registered": [0x13, "altgr"],
    "thorn": [[0x14, "altgr"], [0x19, "altgr"]],
    "THORN": [[0x14, "shift", "altgr"], [0x19, "shift", "altgr"]],
    "leftarrow": [0x15, "altgr"],
    "downarrow": [0x16, "altgr"],
    "uparrow": [0x16, "shift", "altgr"],
    "rightarrow": [0x17, "altgr"],
    "idotless": [0x17, "shift", "altgr"],
    "oe": [0x18, "altgr"],
    "OE": [0x18, "shift", "altgr"],
    "aring": [0x1a],
    "Aring": [0x1a, "shift"],
    "dead_diaeresis": [[0x1a, "altgr"], [0x1b]],
    "dead_abovering": [0x1a, "shift", "altgr"],
    "dead_circumflex": [0x1b, "shift"],
    "dead_tilde": [0x1b, "altgr"],
    "dead_caron": [[0x1b, "shift", "altgr"], [0x28, "shift", "altgr"]],
    "ordfeminine": [[0x1e, "altgr"], [0x21, "shift", "altgr"]],
    "masculine": [[0x1e, "shift", "altgr"], [0x32, "shift", "altgr"]],
    "ssharp": [0x1f, "altgr"],
    "section": [[0x1f, "shift", "altgr"], [0x29, "shift"]],
    "eth": [0x20, "altgr"],
    "ETH": [0x20, "shift", "altgr"],
    "dstroke": [0x21, "altgr"],
    "eng": [0x22, "altgr"],
    "ENG": [0x22, "shift", "altgr"],
    "hstroke": [0x23, "altgr"],
    "Hstroke": [0x23, "shift", "altgr"],
    "kra": [0x25, "altgr"],
    "ae": [0x27],
    "AE": [0x27, "shift"],
    "oslash": [0x28],
    "Ooblique": [0x28, "shift"],
    "threequarters": [0x29, "altgr"],
    "paragraph": [0x29, "shift", "altgr"],
    "apostrophe": [0x2b],
    "asterisk": [0x2b, "shift"],
    "dead_doubleacute": [0x2b, "altgr"],
    "multiply": [0x2b, "shift", "altgr"],
    "copyright": [0x2e, "altgr"],
    "leftdoublequotemark": [0x2f, "altgr"],
    "grave": [0x2f, "shift", "altgr"],
    "rightdoublequotemark": [0x30, "altgr"],
    "mu": [0x32, "altgr"],
    "comma": [0x33],
    "semicolon": [0x33, "shift"],
    "dead_cedilla": [0x33, "altgr"],
    "dead_ogonek": [0x33, "shift", "altgr"],
    "period": [0x34],
    "colon": [0x34, "shift"],
    "periodcentered": [0x34, "altgr"],
    "dead_abovedot": [0x34, "shift", "altgr"],
    "minus": [0x35],
    "underscore": [0x35, "shift"],
    "hyphen": [0x35, "altgr"],
    "macron": [0x35, "shift", "altgr"],
    "nobreakspace": [0x39, "altgr"],
    "less": [0x56],
    "greater": [0x56, "shift"],
    "backslash": [0x56, "altgr"],
    "notsign": [0x56, "shift", "altgr"]
  },
  "de": {
    "map": [0x407],
    "exclam": [0x02, "shift"],
    "onesuperior": [0x02, "altgr"],
    "exclamdown": [0x02, "shift", "altgr"],
    "quotedbl": [0x03, "shift"],
    "twosuperior": [0x03, "altgr"],
    "oneeighth": [0x03, "shift", "altgr"],
    "section": [0x04, "shift"],
    "threesuperior": [0x04, "altgr"],
    "sterling": [0x04, "shift", "altgr"],
    "dollar": [0x05, "shift"],
    "onequarter": [0x05, "altgr"],
    "currency": [0x05, "shift", "altgr"],
    "percent": [0x06, "shift"],
    "onehalf": [0x06, "altgr"],
    "threeeighths": [0x06, "shift", "altgr"],
    "ampersand": [0x07, "shift"],
    "threequarters": [0x07, "altgr"],
    "fiveeighths": [0x07, "shift", "altgr"],
    "slash": [0x08, "shift"],
    "braceleft": [0x08, "altgr"],
    "seveneighths": [0x08, "shift", "altgr"],
    "parenleft": [0x09, "shift"],
    "bracketleft": [0x09, "altgr"],
    "trademark": [0x09, "shift", "altgr"],
    "parenright": [0x0a, "shift"],
    "bracketright": [0x0a, "altgr"],
    "plusminus": [0x0a, "shift", "altgr"],
    "equal": [0x0b, "shift"],
    "braceright": [0x0b, "altgr"],
    "ssharp": [0x0c],
    "question": [0x0c, "shift"],
    "backslash": [0x0c, "altgr"],
    "questiondown": [0x0c, "shift", "altgr"],
    "acute": [0x0d],
    "dead_acute": [0x0d],
    "grave": [0x0d, "shift"],
    "dead_grave": [0x0d, "shift"],
    "dead_cedilla": [0x0d, "altgr"],
    "dead_ogonek": [0x0d, "shift", "altgr"],
    "at": [0x10, "altgr"],
    "Greek_OMEGA": [0x10, "shift", "altgr"],
    "EuroSign": [0x12, "altgr"],
    "paragraph": [0x13, "altgr"],
    "registered": [0x13, "shift", "altgr"],
    "tslash": [0x14, "altgr"],
    "Tslash": [0x14, "shift", "altgr"],
    "z": [0x15],
    "leftarrow": [0x15, "altgr"],
    "yen": [0x15, "shift", "altgr"],
    "downarrow": [0x16, "altgr"],
    "uparrow": [0x16, "shift", "altgr"],
    "rightarrow": [0x17, "altgr"],
    "idotless": [0x17, "shift", "altgr"],
    "oslash": [0x18, "altgr"],
    "Ooblique": [0x18, "shift", "altgr"],
    "thorn": [0x19, "altgr"],
    "THORN": [0x19, "shift", "altgr"],
    "udiaeresis": [0x1a],
    "Udiaeresis": [0x1a, "shift"],
    "dead_diaeresis": [0x1a, "altgr"],
    "dead_abovering": [0x1a, "shift", "altgr"],
    "plus": [0x1b],
    "asterisk": [0x1b, "shift"],
    "asciitilde": [0x1b, "altgr"],
    "dead_tilde": [0x1b, "altgr"],
    "dead_macron": [0x1b, "shift", "altgr"],
    "ae": [0x1e, "altgr"],
    "AE": [0x1e, "shift", "altgr"],
    "eth": [0x20, "altgr"],
    "ETH": [0x20, "shift", "altgr"],
    "dstroke": [0x21, "altgr"],
    "ordfeminine": [0x21, "shift", "altgr"],
    "eng": [0x22, "altgr"],
    "ENG": [0x22, "shift", "altgr"],
    "hstroke": [0x23, "altgr"],
    "Hstroke": [0x23, "shift", "altgr"],
    "kra": [0x25, "altgr"],
    "odiaeresis": [0x27],
    "Odiaeresis": [0x27, "shift"],
    "dead_doubleacute": [0x27, "altgr"],
    "adiaeresis": [0x28],
    "Adiaeresis": [0x28, "shift"],
    "dead_caron": [0x28, "shift", "altgr"],
    "asciicircum": [0x29],
    "dead_circumflex": [0x29],
    "degree": [0x29, "shift"],
    "notsign": [0x29, "altgr"],
    "numbersign": [0x2b],
    "apostrophe": [0x2b, "shift"],
    "dead_breve": [0x2b, "shift", "altgr"],
    "y": [0x2c],
    "guillemotleft": [0x2c, "altgr"],
    "guillemotright": [0x2d, "altgr"],
    "cent": [0x2e, "altgr"],
    "copyright": [0x2e, "shift", "altgr"],
    "leftdoublequotemark": [0x2f, "altgr"],
    "rightdoublequotemark": [0x30, "altgr"],
    "mu": [0x32, "altgr"],
    "masculine": [0x32, "shift", "altgr"],
    "comma": [0x33],
    "semicolon": [0x33, "shift"],
    "horizconnector": [0x33, "altgr"],
    "multiply": [0x33, "shift", "altgr"],
    "period": [0x34],
    "colon": [0x34, "shift"],
    "periodcentered": [0x34, "altgr"],
    "division": [0x34, "shift", "altgr"],
    "minus": [0x35],
    "underscore": [0x35, "shift"],
    "dead_belowdot": [0x35, "altgr"],
    "dead_abovedot": [0x35, "shift", "altgr"]
  },
  "de-ch": {
    "map": [0x00000807],
    "section": [0x29],
    "degree": [0x29, "shift"],
    "notsign": [0x07, "altgr"],
    "plus": [0x2, "shift"],
    "brokenbar": [0x02, "altgr"],
    "quotedbl": [0x03, "shift"],
    "at": [0x03, "altgr"],
    "asterisk": [0x04, "shift"],
    "numbersign": [0x04, "altgr"],
    "ccedilla": [0x05, "shift"],
    "percent": [0x06, "shift"],
    "ampersand": [0x07, "shift"],
    "slash": [0x08, "shift"],
    "bar": [0x08, "altgr"],
    "parenleft": [0x09, "shift"],
    "cent": [0x09, "altgr"],
    "parenright": [0x0a, "shift"],
    "equal": [0x0b, "shift"],
    "apostrophe": [0x0c],
    "question": [0x0c, "shift"],
    "dead_acute": [0x0c, "altgr"],
    "dead_circumflex": [0x0d],
    "dead_grave": [0x0d, "shift"],
    "dead_tilde": [0x0d, "altgr"],
    "EuroSign": [0x12, "altgr"],
    "z": [0x15],
    "udiaeresis": [0x1a],
    "egrave": [0x1a, "shift"],
    "bracketleft": [0x1a, "altgr"],
    "dead_diaeresis": [0x1b],
    "exclam": [0x1b, "shift"],
    "bracketright": [0x1b, "altgr"],
    "odiaeresis": [0x27],
    "eacute": [0x27, "shift"],
    "adiaeresis": [0x28],
    "agrave": [0x28, "shift"],
    "braceleft": [0x28, "altgr"],
    "dollar": [0x2b],
    "sterling": [0x2b, "shift"],
    "braceright": [0x2b, "altgr"],
    "backslash": [0x56, "altgr"],
    "y": [0x2c],
    "comma": [0x33],
    "semicolon": [0x33, "shift"],
    "period": [0x34],
    "colon": [0x34, "shift"],
    "minus": [0x35],
    "underscore": [0x35, "shift"]
  },
  "en-gb": {
    "map": [0x809],
    "exclam": [0x02, "shift"],
    "onesuperior": [0x02, "altgr"],
    "exclamdown": [0x02, "shift", "altgr"],
    "quotedbl": [0x03, "shift"],
    "twosuperior": [0x03, "altgr"],
    "oneeighth": [0x03, "shift", "altgr"],
    "sterling": [0x04, "shift"],
    "threesuperior": [0x04, "altgr"],
    "dollar": [0x05, "shift"],
    "EuroSign": [0x05, "altgr"],
    "percent": [0x06, "shift"],
    "onehalf": [0x06, "altgr"],
    "threeeighths": [0x06, "shift", "altgr"],
    "asciicircum": [0x07, "shift"],
    "threequarters": [0x07, "altgr"],
    "fiveeighths": [0x07, "shift", "altgr"],
    "ampersand": [0x08, "shift"],
    "braceleft": [[0x08, "altgr"], [0x1a, "shift"]],
    "seveneighths": [0x08, "shift", "altgr"],
    "asterisk": [0x09, "shift"],
    "bracketleft": [[0x09, "altgr"], [0x1a]],
    "trademark": [0x09, "shift", "altgr"],
    "parenleft": [0x0a, "shift"],
    "bracketright": [[0x0a, "altgr"], [0x1b]],
    "plusminus": [0x0a, "shift", "altgr"],
    "parenright": [0x0b, "shift"],
    "braceright": [[0x0b, "altgr"], [0x1b, "shift"]],
    "degree": [0x0b, "shift", "altgr"],
    "minus": [0x0c],
    "underscore": [0x0c, "shift"],
    "backslash": [[0x0c, "altgr"], [0x56]],
    "questiondown": [0x0c, "shift", "altgr"],
    "equal": [0x0d],
    "plus": [0x0d, "shift"],
    "dead_cedilla": [0x0d, "altgr"],
    "dead_ogonek": [0x0d, "shift", "altgr"],
    "at": [[0x10, "altgr"], [0x28, "shift"]],
    "Greek_OMEGA": [0x10, "shift", "altgr"],
    "lstroke": [[0x11, "altgr"], [0x26, "altgr"]],
    "Lstroke": [[0x11, "shift", "altgr"], [0x26, "shift", "altgr"]],
    "paragraph": [0x13, "altgr"],
    "registered": [0x13, "shift", "altgr"],
    "tslash": [0x14, "altgr"],
    "Tslash": [0x14, "shift", "altgr"],
    "leftarrow": [0x15, "altgr"],
    "yen": [0x15, "shift", "altgr"],
    "downarrow": [0x16, "altgr"],
    "uparrow": [0x16, "shift", "altgr"],
    "rightarrow": [0x17, "altgr"],
    "idotless": [0x17, "shift", "altgr"],
    "oslash": [0x18, "altgr"],
    "Ooblique": [0x18, "shift", "altgr"],
    "thorn": [0x19, "altgr"],
    "THORN": [0x19, "shift", "altgr"],
    "dead_diaeresis": [0x1a, "altgr"],
    "dead_abovering": [0x1a, "shift", "altgr"],
    "dead_tilde": [0x1b, "altgr"],
    "dead_macron": [0x1b, "shift", "altgr"],
    "ae": [0x1e, "altgr"],
    "AE": [0x1e, "shift", "altgr"],
    "ssharp": [0x1f, "altgr"],
    "section": [0x1f, "shift", "altgr"],
    "eth": [0x20, "altgr"],
    "ETH": [0x20, "shift", "altgr"],
    "dstroke": [0x21, "altgr"],
    "ordfeminine": [0x21, "shift", "altgr"],
    "eng": [0x22, "altgr"],
    "ENG": [0x22, "shift", "altgr"],
    "hstroke": [0x23, "altgr"],
    "Hstroke": [0x23, "shift", "altgr"],
    "kra": [0x25, "altgr"],
    "semicolon": [0x27],
    "colon": [0x27, "shift"],
    "dead_acute": [0x27, "altgr"],
    "dead_doubleacute": [0x27, "shift", "altgr"],
    "apostrophe": [0x28],
    "dead_circumflex": [0x28, "altgr"],
    "dead_caron": [0x28, "shift", "altgr"],
    "grave": [0x29],
    "notsign": [0x29, "shift"],
    "bar": [[0x29, "altgr"], [0x56, "shift"]],
    "numbersign": [0x2b],
    "asciitilde": [0x2b, "shift"],
    "dead_grave": [0x2b, "altgr"],
    "dead_breve": [0x2b, "shift", "altgr"],
    "guillemotleft": [0x2c, "altgr"],
    "less": [[0x2c, "shift", "altgr"], [0x33, "shift"]],
    "guillemotright": [0x2d, "altgr"],
    "greater": [[0x2d, "shift", "altgr"], [0x34, "shift"]],
    "cent": [0x2e, "altgr"],
    "copyright": [0x2e, "shift", "altgr"],
    "leftdoublequotemark": [0x2f, "altgr"],
    "rightdoublequotemark": [0x30, "altgr"],
    "mu": [0x32, "altgr"],
    "masculine": [0x32, "shift", "altgr"],
    "comma": [0x33],
    "horizconnector": [0x33, "altgr"],
    "multiply": [0x33, "shift", "altgr"],
    "period": [0x34],
    "periodcentered": [0x34, "altgr"],
    "division": [0x34, "shift", "altgr"],
    "slash": [0x35],
    "question": [0x35, "shift"],
    "dead_belowdot": [0x35, "altgr"],
    "dead_abovedot": [0x35, "shift", "altgr"],
    "eacute": [0x12, "altgr"],
    "aacute": [0x1e, "altgr"],
    "iacute": [0x17, "altgr"],
    "oacute": [0x18, "altgr"],
    "uacute": [0x16, "altgr"]
  },
  "es": {
    "map": [0x40a],
    "exclam": [0x02, "shift"],
    "bar": [0x02, "altgr"],
    "quotedbl": [0x03, "shift"],
    "at": [0x03, "altgr"],
    "oneeighth": [0x03, "shift", "altgr"],
    "periodcentered": [0x04, "shift"],
    "numbersign": [0x04, "altgr"],
    "sterling": [0x04, "shift", "altgr"],
    "dollar": [0x05, "shift"],
    "asciitilde": [0x05, "altgr"],
    "percent": [0x06, "shift"],
    "onehalf": [0x06, "altgr"],
    "threeeighths": [0x06, "shift", "altgr"],
    "ampersand": [0x07, "shift"],
    "notsign": [0x07, "altgr"],
    "fiveeighths": [0x07, "shift", "altgr"],
    "slash": [0x08, "shift"],
    "seveneighths": [0x08, "shift", "altgr"],
    "parenleft": [0x09, "shift"],
    "trademark": [0x09, "shift", "altgr"],
    "parenright": [0x0a, "shift"],
    "plusminus": [0x0a, "shift", "altgr"],
    "equal": [0x0b, "shift"],
    "degree": [0x0b, "shift", "altgr"],
    "apostrophe": [0x0c],
    "question": [0x0c, "shift"],
    "exclamdown": [0x0d],
    "questiondown": [0x0d, "shift"],
    "Greek_OMEGA": [0x10, "shift", "altgr"],
    "lstroke": [[0x11, "altgr"], [0x26, "altgr"]],
    "Lstroke": [[0x11, "shift", "altgr"], [0x26, "shift", "altgr"]],
    "EuroSign": [0x12, "altgr"],
    "paragraph": [0x13, "altgr"],
    "registered": [0x13, "shift", "altgr"],
    "tslash": [0x14, "altgr"],
    "Tslash": [0x14, "shift", "altgr"],
    "leftarrow": [0x15, "altgr"],
    "yen": [0x15, "shift", "altgr"],
    "downarrow": [0x16, "altgr"],
    "uparrow": [0x16, "shift", "altgr"],
    "rightarrow": [0x17, "altgr"],
    "idotless": [0x17, "shift", "altgr"],
    "oslash": [0x18, "altgr"],
    "Ooblique": [0x18, "shift", "altgr"],
    "thorn": [0x19, "altgr"],
    "THORN": [0x19, "shift", "altgr"],
    "dead_grave": [0x1a],
    "dead_circumflex": [0x1a, "shift"],
    "bracketleft": [0x1a, "altgr"],
    "dead_abovering": [0x1a, "shift", "altgr"],
    "plus": [0x1b],
    "asterisk": [0x1b, "shift"],
    "bracketright": [0x1b, "altgr"],
    "dead_macron": [0x1b, "shift", "altgr"],
    "ae": [0x1e, "altgr"],
    "AE": [0x1e, "shift", "altgr"],
    "ssharp": [0x1f, "altgr"],
    "section": [0x1f, "shift", "altgr"],
    "eth": [0x20, "altgr"],
    "ETH": [0x20, "shift", "altgr"],
    "dstroke": [0x21, "altgr"],
    "eng": [0x22, "altgr"],
    "ENG": [0x22, "shift", "altgr"],
    "hstroke": [0x23, "altgr"],
    "Hstroke": [0x23, "shift", "altgr"],
    "kra": [0x25, "altgr"],
    "ntilde": [0x27],
    "Ntilde": [0x27, "shift"],
    "dead_doubleacute": [0x27, "shift", "altgr"],
    "dead_acute": [0x28],
    "dead_diaeresis": [0x28, "shift"],
    "braceleft": [0x28, "altgr"],
    "masculine": [0x29],
    "ordfeminine": [0x29, "shift"],
    "backslash": [0x29, "altgr"],
    "ccedilla": [0x2b],
    "Ccedilla": [0x2b, "shift"],
    "braceright": [0x2b, "altgr"],
    "dead_breve": [0x2b, "shift", "altgr"],
    "guillemotleft": [0x2c, "altgr"],
    "less": [0x56],
    "greater": [0x56, "shift"],
    "guillemotright": [0x2d, "altgr"],
    "cent": [0x2e, "altgr"],
    "copyright": [0x2e, "shift", "altgr"],
    "leftdoublequotemark": [0x2f, "altgr"],
    "grave": [0x2f, "shift", "altgr"],
    "rightdoublequotemark": [0x30, "altgr"],
    "mu": [0x32, "altgr"],
    "comma": [0x33],
    "semicolon": [0x33, "shift"],
    "horizconnector": [0x33, "altgr"],
    "multiply": [0x33, "shift", "altgr"],
    "period": [0x34],
    "colon": [0x34, "shift"],
    "division": [0x34, "shift", "altgr"],
    "minus": [0x35],
    "underscore": [0x35, "shift"],
    "dead_belowdot": [0x35, "altgr"],
    "dead_abovedot": [0x35, "shift", "altgr"]
  },
  "et": {
    "map": [0x00000425],
    "dead_caron": [0x29],
    "dead_tilde": [0x29, "shift"],
    "exclam": [0x2, "shift"],
    "quotedbl": [0x3, "shift"],
    "at": [0x3, "altgr"],
    "numbersign": [0x4, "shift"],
    "sterling": [0x4, "altgr"],
    "currency": [0x5, "shift"],
    "dollar": [0x5, "altgr"],
    "percent": [0x6, "shift"],
    "ampersand": [0x7, "shift"],
    "slash": [0x8, "shift"],
    "braceleft": [0x8, "altgr"],
    "parenleft": [0x9, "shift"],
    "bracketleft": [0x9, "altgr"],
    "parenright": [0xa, "shift"],
    "bracketright": [0xa, "altgr"],
    "equal": [0xb, "shift"],
    "braceright": [0xb, "altgr"],
    "plus": [0xc],
    "question": [0xc, "shift"],
    "backslash": [0xc, "altgr"],
    "acute": [0xd],
    "dead_acute": [0xd],
    "grave": [0xd, "shift"],
    "dead_grave": [0xd, "shift"],
    "EuroSign": [0x12, "altgr"],
    "udiaeresis": [0x1a],
    "Udiaeresis": [0x1a, "shift"],
    "otilde": [0x1b],
    "Otilde": [0x1b, "shift"],
    "section": [0x1b, "altgr"],
    "scaron": [0x1f, "altgr"],
    "Scaron": [0x1f, "altgr", "shift"],
    "odiaeresis": [0x27],
    "Odiaeresis": [0x27, "shift"],
    "adiaeresis": [0x28],
    "Adiaeresis": [0x28, "shift"],
    "asciicircum": [0x28, "altgr"],
    "apostrophe": [0x2b],
    "asterisk": [0x2b, "shift"],
    "onehalf": [0x2b, "altgr"],
    "less": [0x56],
    "greater": [0x56, "shift"],
    "bar": [0x56, "altgr"],
    "zcaron": [0x2c, "altgr"],
    "Zcaron": [0x2c, "altgr", "shift"],
    "comma": [0x33],
    "semicolon": [0x33, "shift"],
    "period": [0x34],
    "colon": [0x34, "shift"],
    "minus": [0x35],
    "underscore": [0x35, "shift"]
  },
  "fo": {
    "map": [0x438],
    "onehalf": [0x29],
    "section": [0x29, "shift"],
    "exclam": [0x2, "shift"],
    "quotedbl": [0x3, "shift"],
    "at": [0x3, "altgr"],
    "numbersign": [0x4, "shift"],
    "sterling": [0x4, "altgr"],
    "currency": [0x5, "shift"],
    "dollar": [0x5, "altgr"],
    "percent": [0x6, "shift"],
    "ampersand": [0x7, "shift"],
    "slash": [0x8, "shift"],
    "braceleft": [0x8, "altgr"],
    "parenleft": [0x9, "shift"],
    "bracketleft": [0x9, "altgr"],
    "parenright": [0xa, "shift"],
    "bracketright": [0xa, "altgr"],
    "equal": [0xb, "shift"],
    "braceright": [0xb, "altgr"],
    "plus": [0xc],
    "question": [0xc, "shift"],
    "plusminus": [0xc, "altgr"],
    "bar": [0xd, "altgr"],
    "dead_acute": [0xd],
    "EuroSign": [0x12, "altgr"],
    "aring": [0x1a],
    "Aring": [0x1a, "shift"],
    "eth": [0x1b],
    "asciitilde": [0x1b, "altgr"],
    "ae": [0x27],
    "oslash": [0x28],
    "Ooblique": [0x28, "shift"],
    "apostrophe": [0x2b],
    "asterisk": [0x2b, "shift"],
    "less": [0x56],
    "greater": [0x56, "shift"],
    "backslash": [0x56, "altgr"],
    "comma": [0x33],
    "semicolon": [0x33, "shift"],
    "period": [0x34],
    "colon": [0x34, "shift"],
    "minus": [0x35],
    "underscore": [0x35, "shift"]
  },
  "fr": {
    "map": [0x40c],
    "twosuperior": [0x29],
    "notsign": [0x29, "altgr"],
    "ampersand": [0x02],
    "1": [0x02, "shift"],
    "onesuperior": [0x02, "altgr"],
    "exclamdown": [0x02, "shift", "altgr"],
    "eacute": [0x03],
    "2": [0x03, "shift"],
    "asciitilde": [0x03, "altgr"],
    "oneeighth": [0x03, "shift", "altgr"],
    "quotedbl": [0x04],
    "3": [0x04, "shift"],
    "numbersign": [0x04, "altgr"],
    "apostrophe": [0x05],
    "4": [0x05, "shift"],
    "braceleft": [0x05, "altgr"],
    "parenleft": [0x06],
    "5": [0x06, "shift"],
    "bracketleft": [0x06, "altgr"],
    "threeeighths": [0x06, "shift", "altgr"],
    "minus": [0x07],
    "6": [0x07, "shift"],
    "bar": [0x07, "altgr"],
    "fiveeighths": [0x07, "shift", "altgr"],
    "egrave": [0x08],
    "7": [0x08, "shift"],
    "grave": [0x08, "altgr"],
    "seveneighths": [0x08, "shift", "altgr"],
    "underscore": [0x09],
    "8": [0x09, "shift"],
    "backslash": [0x09, "altgr"],
    "trademark": [0x09, "shift", "altgr"],
    "ccedilla": [0x0a],
    "9": [0x0a, "shift"],
    "asciicircum": [0x0a, "altgr"],
    "plusminus": [0x0a, "shift", "altgr"],
    "agrave": [0x0b],
    "0": [0x0b, "shift"],
    "at": [0x0b, "altgr"],
    "parenright": [0x0c],
    "degree": [0x0c, "shift"],
    "bracketright": [0x0c, "altgr"],
    "questiondown": [0x0c, "shift", "altgr"],
    "equal": [0x0d],
    "plus": [0x0d, "shift"],
    "braceright": [0x0d, "altgr"],
    "dead_ogonek": [0x0d, "shift", "altgr"],
    "a": [0x10],
    "ae": [0x10, "altgr"],
    "AE": [0x10, "shift", "altgr"],
    "z": [0x11],
    "guillemotleft": [0x11, "altgr"],
    "EuroSign": [0x12, "altgr"],
    "paragraph": [0x13, "altgr"],
    "registered": [0x13, "shift", "altgr"],
    "tslash": [0x14, "altgr"],
    "Tslash": [0x14, "shift", "altgr"],
    "leftarrow": [0x15, "altgr"],
    "yen": [0x15, "shift", "altgr"],
    "downarrow": [0x16, "altgr"],
    "uparrow": [0x16, "shift", "altgr"],
    "rightarrow": [0x17, "altgr"],
    "idotless": [0x17, "shift", "altgr"],
    "oslash": [0x18, "altgr"],
    "Ooblique": [0x18, "shift", "altgr"],
    "thorn": [0x19, "altgr"],
    "THORN": [0x19, "shift", "altgr"],
    "dead_circumflex": [0x1a],
    "dead_diaeresis": [0x1a, "shift"],
    "dead_abovering": [0x1a, "shift", "altgr"],
    "dollar": [0x1b],
    "sterling": [0x1b, "shift"],
    "currency": [0x1b, "altgr"],
    "dead_macron": [0x1b, "shift", "altgr"],
    "q": [0x1e],
    "Greek_OMEGA": [0x1e, "shift", "altgr"],
    "ssharp": [0x1f, "altgr"],
    "eth": [0x20, "altgr"],
    "ETH": [0x20, "shift", "altgr"],
    "dstroke": [0x21, "altgr"],
    "ordfeminine": [0x21, "shift", "altgr"],
    "eng": [0x22, "altgr"],
    "ENG": [0x22, "shift", "altgr"],
    "hstroke": [0x23, "altgr"],
    "Hstroke": [0x23, "shift", "altgr"],
    "kra": [0x25, "altgr"],
    "lstroke": [0x26, "altgr"],
    "Lstroke": [0x26, "shift", "altgr"],
    "m": [0x27],
    "masculine": [0x27, "shift", "altgr"],
    "ugrave": [0x28],
    "percent": [0x28, "shift"],
    "dead_caron": [0x28, "shift", "altgr"],
    "asterisk": [0x2b],
    "mu": [0x2b, "shift"],
    "dead_grave": [0x2b, "altgr"],
    "dead_breve": [0x2b, "shift", "altgr"],
    "less": [0x56],
    "greater": [0x56, "shift"],
    "w": [0x2c],
    "guillemotright": [0x2d, "altgr"],
    "cent": [0x2e, "altgr"],
    "copyright": [0x2e, "shift", "altgr"],
    "leftdoublequotemark": [0x2f, "altgr"],
    "rightdoublequotemark": [0x30, "altgr"],
    "comma": [0x32],
    "question": [0x32, "shift"],
    "dead_acute": [0x32, "altgr"],
    "dead_doubleacute": [0x32, "shift", "altgr"],
    "semicolon": [0x33],
    "period": [0x33, "shift"],
    "horizconnector": [0x33, "altgr"],
    "multiply": [0x33, "shift", "altgr"],
    "colon": [0x34],
    "slash": [0x34, "shift"],
    "periodcentered": [0x34, "altgr"],
    "division": [0x34, "shift", "altgr"],
    "exclam": [0x35],
    "section": [0x35, "shift"],
    "dead_belowdot": [0x35, "altgr"],
    "dead_abovedot": [0x35, "shift", "altgr"]
  },
  "fr-be": {
    "map": [0x80c],
    "ampersand": [0x02],
    "1": [0x02, "shift"],
    "bar": [0x02, "altgr"],
    "exclamdown": [0x02, "shift", "altgr"],
    "eacute": [0x03],
    "2": [0x03, "shift"],
    "at": [0x03, "altgr"],
    "oneeighth": [0x03, "shift", "altgr"],
    "quotedbl": [0x04],
    "3": [0x04, "shift"],
    "numbersign": [0x04, "altgr"],
    "sterling": [[0x04, "shift", "altgr"], [0x2b, "shift"]],
    "apostrophe": [0x05],
    "4": [0x05, "shift"],
    "onequarter": [0x05, "altgr"],
    "dollar": [[0x05, "shift", "altgr"], [0x1b]],
    "parenleft": [0x06],
    "5": [0x06, "shift"],
    "onehalf": [0x06, "altgr"],
    "threeeighths": [0x06, "shift", "altgr"],
    "section": [0x07],
    "6": [0x07, "shift"],
    "asciicircum": [0x07, "altgr"],
    "fiveeighths": [0x07, "shift", "altgr"],
    "egrave": [0x08],
    "7": [0x08, "shift"],
    "braceleft": [[0x08, "altgr"], [0x0a, "altgr"]],
    "seveneighths": [0x08, "shift", "altgr"],
    "exclam": [0x09],
    "8": [0x09, "shift"],
    "bracketleft": [[0x09, "altgr"], [0x1a, "altgr"]],
    "trademark": [0x09, "shift", "altgr"],
    "ccedilla": [0x0a],
    "9": [0x0a, "shift"],
    "plusminus": [0x0a, "shift", "altgr"],
    "agrave": [0x0b],
    "0": [0x0b, "shift"],
    "braceright": [0x0b, "altgr"],
    "degree": [[0x0b, "shift", "altgr"], [0x0c, "shift"]],
    "parenright": [0x0c],
    "backslash": [[0x0c, "altgr"], [0x56, "altgr"]],
    "questiondown": [0x0c, "shift", "altgr"],
    "minus": [0x0d],
    "underscore": [0x0d, "shift"],
    "dead_cedilla": [[0x0d, "altgr"], [0x32, "altgr"]],
    "dead_ogonek": [0x0d, "shift", "altgr"],
    "a": [0x10],
    "Greek_OMEGA": [0x10, "shift", "altgr"],
    "z": [0x11],
    "lstroke": [[0x11, "altgr"], [0x26, "altgr"]],
    "Lstroke": [[0x11, "shift", "altgr"], [0x26, "shift", "altgr"]],
    "EuroSign": [0x12, "altgr"],
    "cent": [[0x12, "shift", "altgr"], [0x2e, "altgr"]],
    "paragraph": [0x13, "altgr"],
    "registered": [0x13, "shift", "altgr"],
    "tslash": [0x14, "altgr"],
    "Tslash": [0x14, "shift", "altgr"],
    "leftarrow": [0x15, "altgr"],
    "yen": [0x15, "shift", "altgr"],
    "downarrow": [0x16, "altgr"],
    "uparrow": [0x16, "shift", "altgr"],
    "rightarrow": [0x17, "altgr"],
    "idotless": [0x17, "shift", "altgr"],
    "oslash": [0x18, "altgr"],
    "Ooblique": [0x18, "shift", "altgr"],
    "thorn": [0x19, "altgr"],
    "THORN": [0x19, "shift", "altgr"],
    "dead_circumflex": [0x1a],
    "dead_diaeresis": [0x1a, "shift"],
    "dead_abovering": [0x1a, "shift", "altgr"],
    "asterisk": [0x1b, "shift"],
    "bracketright": [0x1b, "altgr"],
    "dead_macron": [0x1b, "shift", "altgr"],
    "q": [0x1e],
    "ae": [0x1e, "altgr"],
    "AE": [0x1e, "shift", "altgr"],
    "ssharp": [0x1f, "altgr"],
    "eth": [0x20, "altgr"],
    "ETH": [0x20, "shift", "altgr"],
    "dstroke": [0x21, "altgr"],
    "ordfeminine": [0x21, "shift", "altgr"],
    "eng": [0x22, "altgr"],
    "ENG": [0x22, "shift", "altgr"],
    "hstroke": [0x23, "altgr"],
    "Hstroke": [0x23, "shift", "altgr"],
    "kra": [0x25, "altgr"],
    "m": [0x27],
    "dead_acute": [[0x27, "altgr"], [0x28, "altgr"]],
    "dead_doubleacute": [0x27, "shift", "altgr"],
    "ugrave": [0x28],
    "percent": [0x28, "shift"],
    "dead_caron": [0x28, "shift", "altgr"],
    "twosuperior": [0x29],
    "threesuperior": [0x29, "shift"],
    "notsign": [0x29, "altgr"],
    "mu": [0x2b],
    "dead_grave": [0x2b, "altgr"],
    "dead_breve": [0x2b, "shift", "altgr"],
    "w": [0x2c],
    "guillemotleft": [0x2c, "altgr"],
    "guillemotright": [0x2d, "altgr"],
    "copyright": [0x2e, "shift", "altgr"],
    "leftdoublequotemark": [0x2f, "altgr"],
    "grave": [0x2f, "shift", "altgr"],
    "rightdoublequotemark": [0x30, "altgr"],
    "comma": [0x32],
    "question": [0x32, "shift"],
    "masculine": [0x32, "shift", "altgr"],
    "semicolon": [0x33],
    "period": [0x33, "shift"],
    "horizconnector": [0x33, "altgr"],
    "multiply": [0x33, "shift", "altgr"],
    "colon": [0x34],
    "slash": [0x34, "shift"],
    "periodcentered": [0x34, "altgr"],
    "division": [0x34, "shift", "altgr"],
    "equal": [0x35],
    "plus": [0x35, "shift"],
    "dead_tilde": [0x35, "altgr"],
    "dead_abovedot": [0x35, "shift", "altgr"]
  },
  "fr-ca": {
    "map": [0xc0c],
    "backslash": [0x29, "altgr"],
    "plusminus": [0x2, "altgr"],
    "at": [0x3, "altgr"],
    "sterling": [0x4, "altgr"],
    "cent": [0x5, "altgr"],
    "currency": [0x6, "altgr"],
    "notsign": [0x7, "altgr"],
    "bar": [0x29, "shift"],
    "twosuperior": [0x9, "altgr"],
    "threesuperior": [0xa, "altgr"],
    "onequarter": [0xb, "altgr"],
    "onehalf": [0xc, "altgr"],
    "threequarters": [0xd, "altgr"],
    "section": [0x18, "altgr"],
    "paragraph": [0x19, "altgr"],
    "bracketleft": [0x1a, "altgr"],
    "bracketright": [0x1b, "altgr"],
    "asciitilde": [0x27, "altgr"],
    "braceleft": [0x28, "altgr"],
    "braceright": [0x2b, "altgr"],
    "less": [0x2b],
    "greater": [0x2b, "shift"],
    "guillemotleft": [0x56],
    "guillemotright": [0x56, "shift"],
    "degree": [0x56, "altgr"],
    "mu": [0x32, "altgr"],
    "eacute": [0x35],
    "dead_acute": [0x35, "altgr"],
    "dead_grave": [0x28],
    "dead_circumflex": [[0x1a], [0x1a, "shift"]],
    "dead_cedilla": [0x1b],
    "dead_diaeresis": [0x1b, "shift"],
    "exclam": [0x2, "shift"],
    "quotedbl": [0x3, "shift"],
    "slash": [0x4, "shift"],
    "dollar": [0x5, "shift"],
    "percent": [0x6, "shift"],
    "question": [0x7, "shift"],
    "ampersand": [0x8, "shift"],
    "asterisk": [0x9, "shift"],
    "parenleft": [0xa, "shift"],
    "parenright": [0xb, "shift"],
    "underscore": [0xc, "shift"],
    "plus": [0xd, "shift"]
  },
  "fr-ch": {
    "map": [0x100c],
    "exclam": [0x02, "shift"],
    "onesuperior": [0x02, "altgr"],
    "exclamdown": [0x02, "shift", "altgr"],
    "quotedbl": [0x03, "shift"],
    "twosuperior": [0x03, "altgr"],
    "oneeighth": [0x03, "shift", "altgr"],
    "section": [0x04, "shift"],
    "threesuperior": [0x04, "altgr"],
    "sterling": [0x04, "shift", "altgr"],
    "dollar": [0x05, "shift"],
    "onequarter": [0x05, "altgr"],
    "currency": [0x05, "shift", "altgr"],
    "percent": [0x06, "shift"],
    "onehalf": [0x06, "altgr"],
    "threeeighths": [0x06, "shift", "altgr"],
    "ampersand": [0x07, "shift"],
    "threequarters": [0x07, "altgr"],
    "fiveeighths": [0x07, "shift", "altgr"],
    "slash": [0x08, "shift"],
    "braceleft": [0x08, "altgr"],
    "seveneighths": [0x08, "shift", "altgr"],
    "parenleft": [0x09, "shift"],
    "bracketleft": [0x09, "altgr"],
    "trademark": [0x09, "shift", "altgr"],
    "parenright": [0x0a, "shift"],
    "bracketright": [0x0a, "altgr"],
    "plusminus": [0x0a, "shift", "altgr"],
    "equal": [0x0b, "shift"],
    "braceright": [0x0b, "altgr"],
    "ssharp": [0x0c],
    "question": [0x0c, "shift"],
    "backslash": [0x0c, "altgr"],
    "questiondown": [0x0c, "shift", "altgr"],
    "acute": [0x0d],
    "dead_acute": [0x0d],
    "grave": [0x0d, "shift"],
    "dead_grave": [0x0d, "shift"],
    "dead_cedilla": [0x0d, "altgr"],
    "dead_ogonek": [0x0d, "shift", "altgr"],
    "at": [0x10, "altgr"],
    "Greek_OMEGA": [0x10, "shift", "altgr"],
    "EuroSign": [0x12, "altgr"],
    "paragraph": [0x13, "altgr"],
    "registered": [0x13, "shift", "altgr"],
    "tslash": [0x14, "altgr"],
    "Tslash": [0x14, "shift", "altgr"],
    "z": [0x15],
    "leftarrow": [0x15, "altgr"],
    "yen": [0x15, "shift", "altgr"],
    "downarrow": [0x16, "altgr"],
    "uparrow": [0x16, "shift", "altgr"],
    "rightarrow": [0x17, "altgr"],
    "idotless": [0x17, "shift", "altgr"],
    "oslash": [0x18, "altgr"],
    "Ooblique": [0x18, "shift", "altgr"],
    "thorn": [0x19, "altgr"],
    "THORN": [0x19, "shift", "altgr"],
    "udiaeresis": [0x1a],
    "Udiaeresis": [0x1a, "shift"],
    "dead_diaeresis": [0x1a, "altgr"],
    "dead_abovering": [0x1a, "shift", "altgr"],
    "plus": [0x1b],
    "asterisk": [0x1b, "shift"],
    "asciitilde": [0x1b, "altgr"],
    "dead_tilde": [0x1b, "altgr"],
    "dead_macron": [0x1b, "shift", "altgr"],
    "ae": [0x1e, "altgr"],
    "AE": [0x1e, "shift", "altgr"],
    "eth": [0x20, "altgr"],
    "ETH": [0x20, "shift", "altgr"],
    "dstroke": [0x21, "altgr"],
    "ordfeminine": [0x21, "shift", "altgr"],
    "eng": [0x22, "altgr"],
    "ENG": [0x22, "shift", "altgr"],
    "hstroke": [0x23, "altgr"],
    "Hstroke": [0x23, "shift", "altgr"],
    "kra": [0x25, "altgr"],
    "odiaeresis": [0x27],
    "Odiaeresis": [0x27, "shift"],
    "dead_doubleacute": [0x27, "altgr"],
    "adiaeresis": [0x28],
    "Adiaeresis": [0x28, "shift"],
    "dead_caron": [0x28, "shift", "altgr"],
    "asciicircum": [0x29],
    "dead_circumflex": [0x29],
    "degree": [0x29, "shift"],
    "notsign": [0x29, "altgr"],
    "numbersign": [0x2b],
    "apostrophe": [0x2b, "shift"],
    "dead_breve": [0x2b, "shift", "altgr"],
    "y": [0x2c],
    "guillemotleft": [0x2c, "altgr"],
    "guillemotright": [0x2d, "altgr"],
    "cent": [0x2e, "altgr"],
    "copyright": [0x2e, "shift", "altgr"],
    "leftdoublequotemark": [0x2f, "altgr"],
    "rightdoublequotemark": [0x30, "altgr"],
    "mu": [0x32, "altgr"],
    "masculine": [0x32, "shift", "altgr"],
    "comma": [0x33],
    "semicolon": [0x33, "shift"],
    "horizconnector": [0x33, "altgr"],
    "multiply": [0x33, "shift", "altgr"],
    "period": [0x34],
    "colon": [0x34, "shift"],
    "periodcentered": [0x34, "altgr"],
    "division": [0x34, "shift", "altgr"],
    "minus": [0x35],
    "underscore": [0x35, "shift"],
    "dead_belowdot": [0x35, "altgr"],
    "dead_abovedot": [0x35, "shift", "altgr"]
  },
  "hr": {
    "map": [0x41a],
    "exclam": [0x02, "shift"],
    "asciitilde": [0x02, "altgr"],
    "dead_tilde": [0x02, "shift", "altgr"],
    "quotedbl": [0x03, "shift"],
    "dead_caron": [[0x03, "altgr"], [0x28, "shift", "altgr"]],
    "caron": [0x03, "shift", "altgr"],
    "numbersign": [0x04, "shift"],
    "asciicircum": [0x04, "altgr"],
    "dead_circumflex": [0x04, "shift", "altgr"],
    "dollar": [0x05, "shift"],
    "dead_breve": [[0x05, "altgr"], [0x2b, "shift", "altgr"]],
    "breve": [0x05, "shift", "altgr"],
    "percent": [0x06, "shift"],
    "degree": [0x06, "altgr"],
    "dead_abovering": [[0x06, "shift", "altgr"], [0x1a, "shift", "altgr"]],
    "ampersand": [[0x07, "shift"], [0x25, "shift", "altgr"]],
    "dead_ogonek": [0x07, "altgr"],
    "ogonek": [0x07, "shift", "altgr"],
    "slash": [0x08, "shift"],
    "grave": [[0x08, "altgr"], [0x2f, "shift", "altgr"]],
    "dead_grave": [0x08, "shift", "altgr"],
    "parenleft": [0x09, "shift"],
    "abovedot": [0x09, "shift", "altgr"],
    "parenright": [0x0a, "shift"],
    "dead_acute": [[0x0a, "altgr"], [0x27, "altgr"]],
    "apostrophe": [[0x0a, "shift", "altgr"], [0x30, "shift", "altgr"], [0x0c]],
    "equal": [0x0b, "shift"],
    "dead_doubleacute": [[0x0b, "altgr"], [0x27, "shift", "altgr"]],
    "doubleacute": [0x0b, "shift", "altgr"],
    "question": [0x0c, "shift"],
    "dead_diaeresis": [[0x0c, "altgr"], [0x29, "shift"]],
    "diaeresis": [0x0c, "shift", "altgr"],
    "plus": [0x0d],
    "asterisk": [0x0d, "shift"],
    "dead_cedilla": [[0x0d, "altgr"], [0x29]],
    "cedilla": [0x0d, "shift", "altgr"],
    "backslash": [0x10, "altgr"],
    "Greek_OMEGA": [0x10, "shift", "altgr"],
    "bar": [0x11, "altgr"],
    "Lstroke": [[0x11, "shift", "altgr"], [0x26, "altgr"]],
    "lstroke": [0x25, "altgr"],
    "EuroSign": [0x12, "altgr"],
    "paragraph": [0x13, "altgr"],
    "registered": [0x13, "shift", "altgr"],
    "tslash": [0x14, "altgr"],
    "Tslash": [0x14, "shift", "altgr"],
    "z": [0x15],
    "leftarrow": [0x15, "altgr"],
    "yen": [0x15, "shift", "altgr"],
    "downarrow": [0x16, "altgr"],
    "uparrow": [0x16, "shift", "altgr"],
    "rightarrow": [0x17, "altgr"],
    "idotless": [0x17, "shift", "altgr"],
    "oslash": [0x18, "altgr"],
    "Ooblique": [0x18, "shift", "altgr"],
    "thorn": [0x19, "altgr"],
    "THORN": [0x19, "shift", "altgr"],
    "scaron": [0x1a],
    "Scaron": [0x1a, "shift"],
    "division": [[0x1a, "altgr"], [0x34, "shift", "altgr"]],
    "dstroke": [0x1b],
    "Dstroke": [0x1b, "shift"],
    "multiply": [[0x1b, "altgr"], [0x33, "shift", "altgr"]],
    "dead_macron": [0x1b, "shift", "altgr"],
    "ae": [0x1e, "altgr"],
    "AE": [0x1e, "shift", "altgr"],
    "ssharp": [[0x1f, "altgr"], [0x28, "altgr"]],
    "section": [[0x1f, "shift", "altgr"], [0x32, "altgr"]],
    "eth": [0x20, "altgr"],
    "ETH": [0x20, "shift", "altgr"],
    "bracketleft": [0x21, "altgr"],
    "ordfeminine": [0x21, "shift", "altgr"],
    "bracketright": [0x22, "altgr"],
    "ENG": [0x22, "shift", "altgr"],
    "hstroke": [0x23, "altgr"],
    "Hstroke": [0x23, "shift", "altgr"],
    "ccaron": [0x27],
    "Ccaron": [0x27, "shift"],
    "cacute": [0x28],
    "Cacute": [0x28, "shift"],
    "notsign": [0x29, "altgr"],
    "zcaron": [0x2b],
    "Zcaron": [0x2b, "shift"],
    "currency": [0x2b, "altgr"],
    "y": [0x2c],
    "guillemotleft": [0x2c, "altgr"],
    "less": [0x2c, "shift", "altgr"],
    "guillemotright": [0x2d, "altgr"],
    "greater": [0x2d, "shift", "altgr"],
    "cent": [0x2e, "altgr"],
    "copyright": [0x2e, "shift", "altgr"],
    "at": [0x2f, "altgr"],
    "braceleft": [0x30, "altgr"],
    "braceright": [0x31, "altgr"],
    "masculine": [0x32, "shift", "altgr"],
    "comma": [0x33],
    "semicolon": [0x33, "shift"],
    "horizconnector": [0x33, "altgr"],
    "period": [0x34],
    "colon": [0x34, "shift"],
    "periodcentered": [0x34, "altgr"],
    "minus": [0x35],
    "underscore": [0x35, "shift"],
    "dead_belowdot": [0x35, "altgr"],
    "dead_abovedot": [[0x35, "shift", "altgr"], [0x09, "altgr"]]
  },
  "hu": {
    "map": [0x40e],
    "notsign": [0x29, "altgr"],
    "asciitilde": [0x02, "altgr"],
    "caron": [0x03, "altgr"],
    "asciicircum": [0x04, "altgr"],
    "breve": [0x05, "altgr"],
    "degree": [0x06, "altgr"],
    "ogonek": [0x07, "altgr"],
    "grave": [0x08, "altgr"],
    "abovedot": [0x09, "altgr"],
    "acute": [0x0a, "altgr"],
    "doubleacute": [0x0b, "altgr"],
    "diaeresis": [0x0c, "altgr"],
    "cedilla": [0x0d, "altgr"],
    "backslash": [0x10, "altgr"],
    "bar": [0x11, "altgr"],
    "EuroSign": [0x12, "altgr"],
    "Iacute": [0x17, "altgr"],
    "division": [0x1a, "altgr"],
    "multiply": [0x1b, "altgr"],
    "dstroke": [0x1f, "altgr"],
    "Dstroke": [0x20, "altgr"],
    "bracketleft": [0x21, "altgr"],
    "bracketright": [0x22, "altgr"],
    "iacute": [0x24, "altgr"],
    "lstroke": [0x25, "altgr"],
    "Lstroke": [0x26, "altgr"],
    "dollar": [0x27, "altgr"],
    "ssharp": [0x28, "altgr"],
    "currency": [0x2b, "altgr"],
    "less": [0x56, "altgr"],
    "greater": [0x2c, "altgr"],
    "numbersign": [0x2d, "altgr"],
    "ampersand": [0x2e, "altgr"],
    "at": [0x2f, "altgr"],
    "braceleft": [0x30, "altgr"],
    "braceright": [0x31, "altgr"],
    "semicolon": [0x33, "altgr"],
    "asterisk": [0x35, "altgr"],
    "section": [0x29, "shift"],
    "apostrophe": [0x02, "shift"],
    "quotedbl": [0x03, "shift"],
    "plus": [0x04, "shift"],
    "exclam": [0x05, "shift"],
    "percent": [0x06, "shift"],
    "slash": [0x07, "shift"],
    "equal": [0x08, "shift"],
    "parenleft": [0x09, "shift"],
    "parenright": [0x0a, "shift"],
    "Odiaeresis": [0x0b, "shift"],
    "Udiaeresis": [0x0c, "shift"],
    "Oacute": [0x0d, "shift"],
    "Z": [0x15, "shift"],
    "Odoubleacute": [0x1a, "shift"],
    "Uacute": [0x1b, "shift"],
    "Eacute": [0x27, "shift"],
    "Aacute": [0x28, "shift"],
    "Udoubleacute": [0x2b, "shift"],
    "Y": [0x2c, "shift"],
    "question": [0x33, "shift"],
    "colon": [0x34, "shift"],
    "underscore": [0x35, "shift"],
    "F13": [0x3b, "shift"],
    "F14": [0x3c, "shift"],
    "F15": [0x3d, "shift"],
    "F16": [0x3e, "shift"],
    "F17": [0x3f, "shift"],
    "F18": [0x40, "shift"],
    "F19": [0x41, "shift"],
    "F20": [0x42, "shift"],
    "F21": [0x43, "shift"],
    "F22": [0x44, "shift"],
    "F23": [0x57, "shift"],
    "F24": [0x58, "shift"],
    "F25": [0x3b, "ctrl"],
    "F26": [0x3c, "ctrl"],
    "F27": [0x3d, "ctrl"],
    "F28": [0x3e, "ctrl"],
    "F29": [0x3f, "ctrl"],
    "F30": [0x40, "ctrl"],
    "F31": [0x41, "ctrl"],
    "F32": [0x42, "ctrl"],
    "F33": [0x43, "ctrl"],
    "F34": [0x44, "ctrl"],
    "F35": [0x57, "ctrl"],
    "0": [0x29],
    "odiaeresis": [0x0b],
    "udiaeresis": [0x0c],
    "oacute": [0x0d],
    "z": [0x15],
    "odoubleacute": [0x1a],
    "uacute": [0x1b],
    "eacute": [0x27],
    "aacute": [0x28],
    "udoubleacute": [0x2b],
    "y": [0x2c],
    "comma": [0x33],
    "period": [0x34],
    "minus": [0x35]
  },
  "is": {
    "map": [0x40f],
    "exclam": [0x02, "shift"],
    "onesuperior": [0x02, "altgr"],
    "exclamdown": [0x02, "shift", "altgr"],
    "quotedbl": [0x03, "shift"],
    "twosuperior": [0x03, "altgr"],
    "oneeighth": [0x03, "shift", "altgr"],
    "numbersign": [0x04, "shift"],
    "threesuperior": [0x04, "altgr"],
    "sterling": [0x04, "shift", "altgr"],
    "dollar": [0x05, "shift"],
    "onequarter": [0x05, "altgr"],
    "currency": [0x05, "shift", "altgr"],
    "percent": [0x06, "shift"],
    "onehalf": [0x06, "altgr"],
    "threeeighths": [0x06, "shift", "altgr"],
    "ampersand": [0x07, "shift"],
    "threequarters": [0x07, "altgr"],
    "fiveeighths": [0x07, "shift", "altgr"],
    "slash": [0x08, "shift"],
    "braceleft": [0x08, "altgr"],
    "seveneighths": [0x08, "shift", "altgr"],
    "parenleft": [0x09, "shift"],
    "bracketleft": [0x09, "altgr"],
    "trademark": [0x09, "shift", "altgr"],
    "parenright": [0x0a, "shift"],
    "bracketright": [0x0a, "altgr"],
    "plusminus": [0x0a, "shift", "altgr"],
    "equal": [0x0b, "shift"],
    "braceright": [0x0b, "altgr"],
    "odiaeresis": [0x0c],
    "Odiaeresis": [0x0c, "shift"],
    "backslash": [0x0c, "altgr"],
    "questiondown": [0x0c, "shift", "altgr"],
    "minus": [0x0d],
    "underscore": [0x0d, "shift"],
    "dead_cedilla": [0x0d, "altgr"],
    "dead_ogonek": [0x0d, "shift", "altgr"],
    "at": [0x10, "altgr"],
    "Greek_OMEGA": [0x10, "shift", "altgr"],
    "EuroSign": [0x12, "altgr"],
    "paragraph": [0x13, "altgr"],
    "registered": [0x13, "shift", "altgr"],
    "tslash": [0x14, "altgr"],
    "Tslash": [0x14, "shift", "altgr"],
    "leftarrow": [0x15, "altgr"],
    "yen": [0x15, "shift", "altgr"],
    "downarrow": [0x16, "altgr"],
    "uparrow": [0x16, "shift", "altgr"],
    "rightarrow": [0x17, "altgr"],
    "idotless": [0x17, "shift", "altgr"],
    "oslash": [0x18, "altgr"],
    "Ooblique": [0x18, "shift", "altgr"],
    "eth": [0x1a],
    "ETH": [0x1a, "shift"],
    "apostrophe": [0x1b],
    "question": [0x1b, "shift"],
    "asciitilde": [0x1b, "altgr"],
    "dstroke": [0x21, "altgr"],
    "ordfeminine": [0x21, "shift", "altgr"],
    "eng": [0x22, "altgr"],
    "ENG": [0x22, "shift", "altgr"],
    "hstroke": [0x23, "altgr"],
    "Hstroke": [0x23, "shift", "altgr"],
    "kra": [0x25, "altgr"],
    "ae": [0x27],
    "AE": [0x27, "shift"],
    "dead_doubleacute": [0x27, "altgr"],
    "acute": [0x28],
    "dead_acute": [0x28],
    "plus": [0x2b],
    "asterisk": [0x2b, "shift"],
    "grave": [0x2b, "altgr"],
    "guillemotleft": [0x2c, "altgr"],
    "guillemotright": [0x2d, "altgr"],
    "cent": [0x2e, "altgr"],
    "copyright": [0x2e, "shift", "altgr"],
    "leftdoublequotemark": [0x2f, "altgr"],
    "rightdoublequotemark": [0x30, "altgr"],
    "mu": [0x32, "altgr"],
    "masculine": [0x32, "shift", "altgr"],
    "comma": [0x33],
    "semicolon": [0x33, "shift"],
    "horizconnector": [0x33, "altgr"],
    "multiply": [0x33, "shift", "altgr"],
    "period": [0x34],
    "colon": [0x34, "shift"],
    "periodcentered": [0x34, "altgr"],
    "division": [0x34, "shift", "altgr"],
    "thorn": [0x35],
    "THORN": [0x35, "shift"],
    "dead_belowdot": [0x35, "altgr"],
    "dead_abovedot": [0x35, "shift", "altgr"]
  },
  "it": {
    "map": [0x410],
    "exclam": [0x02, "shift"],
    "onesuperior": [0x02, "altgr"],
    "exclamdown": [0x02, "shift", "altgr"],
    "quotedbl": [0x03, "shift"],
    "twosuperior": [0x03, "altgr"],
    "oneeighth": [0x03, "shift", "altgr"],
    "sterling": [0x04, "shift"],
    "threesuperior": [0x04, "altgr"],
    "dollar": [0x05, "shift"],
    "onequarter": [0x05, "altgr"],
    "percent": [0x06, "shift"],
    "onehalf": [0x06, "altgr"],
    "threeeighths": [0x06, "shift", "altgr"],
    "ampersand": [0x07, "shift"],
    "threequarters": [0x07, "altgr"],
    "fiveeighths": [0x07, "shift", "altgr"],
    "slash": [0x08, "shift"],
    "braceleft": [0x08, "altgr"],
    "seveneighths": [0x08, "shift", "altgr"],
    "parenleft": [0x09, "shift"],
    "trademark": [0x09, "shift", "altgr"],
    "parenright": [0x0a, "shift"],
    "plusminus": [0x0a, "shift", "altgr"],
    "equal": [0x0b, "shift"],
    "braceright": [0x0b, "altgr"],
    "degree": [[0x0b, "shift", "altgr"], [0x28, "shift"]],
    "apostrophe": [0x0c],
    "question": [0x0c, "shift"],
    "grave": [[0x0c, "altgr"], [0x2f, "shift", "altgr"]],
    "questiondown": [0x0c, "shift", "altgr"],
    "igrave": [0x0d],
    "asciicircum": [0x0d, "shift"],
    "asciitilde": [0x0d, "altgr"],
    "dead_ogonek": [0x0d, "shift", "altgr"],
    "at": [[0x10, "altgr"], [0x27, "altgr"]],
    "Greek_OMEGA": [0x10, "shift", "altgr"],
    "lstroke": [[0x11, "altgr"], [0x26, "altgr"]],
    "Lstroke": [[0x11, "shift", "altgr"], [0x26, "shift", "altgr"]],
    "EuroSign": [0x12, "altgr"],
    "cent": [[0x12, "shift", "altgr"], [0x2e, "altgr"]],
    "paragraph": [0x13, "altgr"],
    "registered": [0x13, "shift", "altgr"],
    "tslash": [0x14, "altgr"],
    "Tslash": [0x14, "shift", "altgr"],
    "leftarrow": [0x15, "altgr"],
    "yen": [0x15, "shift", "altgr"],
    "downarrow": [0x16, "altgr"],
    "uparrow": [0x16, "shift", "altgr"],
    "rightarrow": [0x17, "altgr"],
    "idotless": [0x17, "shift", "altgr"],
    "oslash": [0x18, "altgr"],
    "Ooblique": [0x18, "shift", "altgr"],
    "thorn": [0x19, "altgr"],
    "THORN": [0x19, "shift", "altgr"],
    "egrave": [0x1a],
    "eacute": [0x1a, "shift"],
    "bracketleft": [0x1a, "altgr"],
    "dead_abovering": [0x1a, "shift", "altgr"],
    "plus": [0x1b],
    "asterisk": [0x1b, "shift"],
    "bracketright": [0x1b, "altgr"],
    "dead_macron": [0x1b, "shift", "altgr"],
    "ae": [0x1e, "altgr"],
    "AE": [0x1e, "shift", "altgr"],
    "ssharp": [0x1f, "altgr"],
    "section": [[0x1f, "shift", "altgr"], [0x2b, "shift"]],
    "eth": [0x20, "altgr"],
    "ETH": [0x20, "shift", "altgr"],
    "dstroke": [0x21, "altgr"],
    "ordfeminine": [0x21, "shift", "altgr"],
    "eng": [0x22, "altgr"],
    "ENG": [0x22, "shift", "altgr"],
    "hstroke": [0x23, "altgr"],
    "Hstroke": [0x23, "shift", "altgr"],
    "kra": [0x25, "altgr"],
    "ograve": [0x27],
    "ccedilla": [0x27, "shift"],
    "dead_doubleacute": [0x27, "shift", "altgr"],
    "agrave": [0x28],
    "numbersign": [0x28, "altgr"],
    "backslash": [0x29],
    "bar": [0x29, "shift"],
    "notsign": [0x29, "altgr"],
    "ugrave": [0x2b],
    "dead_grave": [0x2b, "altgr"],
    "dead_breve": [0x2b, "shift", "altgr"],
    "guillemotleft": [0x2c, "altgr"],
    "guillemotright": [0x2d, "altgr"],
    "copyright": [0x2e, "shift", "altgr"],
    "leftdoublequotemark": [0x2f, "altgr"],
    "rightdoublequotemark": [0x30, "altgr"],
    "mu": [0x32, "altgr"],
    "masculine": [0x32, "shift", "altgr"],
    "comma": [0x33],
    "semicolon": [0x33, "shift"],
    "horizconnector": [0x33, "altgr"],
    "multiply": [0x33, "shift", "altgr"],
    "period": [0x34],
    "colon": [0x34, "shift"],
    "periodcentered": [0x34, "altgr"],
    "division": [0x34, "shift", "altgr"],
    "minus": [0x35],
    "underscore": [0x35, "shift"],
    "dead_belowdot": [0x35, "altgr"],
    "dead_abovedot": [0x35, "shift", "altgr"]
  },
  "ja": {
    "map": [0x411],
    "exclam": [0x02, "shift"],
    "kana_NU": [0x02, "altgr"],
    "quotedbl": [0x03, "shift"],
    "kana_FU": [0x03, "altgr"],
    "numbersign": [0x04, "shift"],
    "kana_A": [0x04, "altgr"],
    "kana_a": [0x04, "shift", "altgr"],
    "dollar": [0x05, "shift"],
    "kana_U": [0x05, "altgr"],
    "kana_u": [0x05, "shift", "altgr"],
    "percent": [0x06, "shift"],
    "kana_E": [0x06, "altgr"],
    "kana_e": [0x06, "shift", "altgr"],
    "ampersand": [0x07, "shift"],
    "kana_O": [0x07, "altgr"],
    "kana_o": [0x07, "shift", "altgr"],
    "apostrophe": [0x08, "shift"],
    "kana_YA": [0x08, "altgr"],
    "kana_ya": [0x08, "shift", "altgr"],
    "parenleft": [0x09, "shift"],
    "kana_YU": [0x09, "altgr"],
    "kana_yu": [0x09, "shift", "altgr"],
    "parenright": [0x0a, "shift"],
    "kana_YO": [0x0a, "altgr"],
    "kana_yo": [0x0a, "shift", "altgr"],
    "asciitilde": [[0x0b, "shift"], [0x0d, "shift"]],
    "kana_WA": [0x0b, "altgr"],
    "kana_WO": [0x0b, "shift", "altgr"],
    "minus": [0x0c],
    "equal": [0x0c, "shift"],
    "kana_HO": [0x0c, "altgr"],
    "asciicircum": [0x0d],
    "kana_HE": [0x0d, "altgr"],
    "kana_TA": [0x10, "altgr"],
    "kana_TE": [0x11, "altgr"],
    "kana_I": [0x12, "altgr"],
    "kana_i": [0x12, "shift", "altgr"],
    "kana_SU": [0x13, "altgr"],
    "kana_KA": [0x14, "altgr"],
    "kana_N": [0x15, "altgr"],
    "kana_NA": [0x16, "altgr"],
    "kana_NI": [0x17, "altgr"],
    "kana_RA": [0x18, "altgr"],
    "kana_SE": [0x19, "altgr"],
    "at": [0x1a],
    "grave": [0x1a, "shift"],
    "voicedsound": [0x1a, "altgr"],
    "bracketleft": [0x1b],
    "braceleft": [0x1b, "shift"],
    "semivoicedsound": [0x1b, "altgr"],
    "kana_openingbracket": [0x1b, "shift", "altgr"],
    "kana_CHI": [0x1e, "altgr"],
    "kana_TO": [0x1f, "altgr"],
    "kana_SHI": [0x20, "altgr"],
    "kana_HA": [0x21, "altgr"],
    "kana_KI": [0x22, "altgr"],
    "kana_KU": [0x23, "altgr"],
    "kana_MA": [0x24, "altgr"],
    "kana_NO": [0x25, "altgr"],
    "kana_RI": [0x26, "altgr"],
    "semicolon": [0x27],
    "plus": [0x27, "shift"],
    "kana_RE": [0x27, "altgr"],
    "colon": [0x28],
    "asterisk": [0x28, "shift"],
    "kana_KE": [0x28, "altgr"],
    "Zenkaku_Hankaku": [0x29],
    "bracketright": [0x2b],
    "braceright": [0x2b, "shift"],
    "kana_MU": [0x2b, "altgr"],
    "kana_closingbracket": [0x2b, "shift", "altgr"],
    "kana_TSU": [0x2c, "altgr"],
    "kana_tsu": [0x2c, "shift", "altgr"],
    "kana_SA": [0x2d, "altgr"],
    "kana_SO": [0x2e, "altgr"],
    "kana_HI": [0x2f, "altgr"],
    "kana_KO": [0x30, "altgr"],
    "kana_MI": [0x31, "altgr"],
    "kana_MO": [0x32, "altgr"],
    "comma": [0x33],
    "less": [0x33, "shift"],
    "kana_NE": [0x33, "altgr"],
    "kana_comma": [0x33, "shift", "altgr"],
    "period": [0x34],
    "greater": [0x34, "shift"],
    "kana_RU": [0x34, "altgr"],
    "kana_fullstop": [0x34, "shift", "altgr"],
    "slash": [0x35],
    "question": [0x35, "shift"],
    "kana_ME": [0x35, "altgr"],
    "kana_conjunctive": [0x35, "shift", "altgr"],
    "Eisu_toggle": [0x3a, "shift"],
    "Execute": [0x54, "shift"],
    "Kanji": [0x70],
    "backslash": [0x73],
    "yen": [0x7d],
    "bar": [0x7d, "shift"],
    "underscore": [0x73, "shift"],
    "Henkan_Mode": [0x79],
    "Katakana_Real": [0x70],
    "Katakana": [0x70],
    "Muhenkan": [0x7b],
    "Henkan_Mode_Ultra": [0x79],
    "backslash_ja": [0x73]
  },
  "lt": {
    "map": [0x427],
    "exclam": [0x02, "shift"],
    "aogonek": [0x02, "altgr"],
    "Aogonek": [0x02, "shift", "altgr"],
    "at": [0x03, "shift"],
    "ccaron": [0x03, "altgr"],
    "Ccaron": [0x03, "shift", "altgr"],
    "numbersign": [0x04, "shift"],
    "eogonek": [0x04, "altgr"],
    "Eogonek": [0x04, "shift", "altgr"],
    "dollar": [0x05, "shift"],
    "eabovedot": [0x05, "altgr"],
    "Eabovedot": [0x05, "shift", "altgr"],
    "percent": [0x06, "shift"],
    "iogonek": [0x06, "altgr"],
    "Iogonek": [0x06, "shift", "altgr"],
    "asciicircum": [0x07, "shift"],
    "scaron": [0x07, "altgr"],
    "Scaron": [0x07, "shift", "altgr"],
    "ampersand": [0x08, "shift"],
    "uogonek": [0x08, "altgr"],
    "Uogonek": [0x08, "shift", "altgr"],
    "asterisk": [0x09, "shift"],
    "umacron": [0x09, "altgr"],
    "Umacron": [0x09, "shift", "altgr"],
    "parenleft": [0x0a, "shift"],
    "doublelowquotemark": [0x0a, "altgr"],
    "parenright": [0x0b, "shift"],
    "leftdoublequotemark": [0x0b, "altgr"],
    "minus": [0x0c],
    "underscore": [0x0c, "shift"],
    "equal": [0x0d],
    "plus": [0x0d, "shift"],
    "zcaron": [0x0d, "altgr"],
    "Zcaron": [0x0d, "shift", "altgr"],
    "bracketleft": [0x1a],
    "braceleft": [0x1a, "shift"],
    "bracketright": [0x1b],
    "braceright": [0x1b, "shift"],
    "semicolon": [0x27],
    "colon": [0x27, "shift"],
    "apostrophe": [0x28],
    "quotedbl": [0x28, "shift"],
    "grave": [0x29],
    "asciitilde": [0x29, "shift"],
    "backslash": [0x2b],
    "bar": [0x2b, "shift"],
    "comma": [0x33],
    "less": [0x33, "shift"],
    "period": [0x34],
    "greater": [0x34, "shift"],
    "slash": [0x35],
    "question": [0x35, "shift"],
    "endash": [0x56],
    "EuroSign": [0x56, "shift"]
  },
  "lv": {
    "map": [0x426],
    "exclam": [0x02, "shift"],
    "onesuperior": [0x02, "altgr"],
    "exclamdown": [0x02, "shift", "altgr"],
    "at": [[0x03, "shift"], [0x10, "altgr"]],
    "twosuperior": [0x03, "altgr"],
    "oneeighth": [0x03, "shift", "altgr"],
    "numbersign": [0x04, "shift"],
    "threesuperior": [0x04, "altgr"],
    "sterling": [0x04, "shift", "altgr"],
    "dollar": [0x05, "shift"],
    "EuroSign": [0x05, "altgr"],
    "cent": [0x05, "shift", "altgr"],
    "percent": [0x06, "shift"],
    "onehalf": [0x06, "altgr"],
    "threeeighths": [0x06, "shift", "altgr"],
    "asciicircum": [0x07, "shift"],
    "threequarters": [0x07, "altgr"],
    "fiveeighths": [0x07, "shift", "altgr"],
    "ampersand": [0x08, "shift"],
    "braceleft": [[0x08, "altgr"], [0x1a, "shift"]],
    "seveneighths": [0x08, "shift", "altgr"],
    "asterisk": [0x09, "shift"],
    "bracketleft": [[0x09, "altgr"], [0x1a]],
    "trademark": [0x09, "shift", "altgr"],
    "parenleft": [0x0a, "shift"],
    "bracketright": [[0x0a, "altgr"], [0x1b]],
    "plusminus": [0x0a, "shift", "altgr"],
    "parenright": [0x0b, "shift"],
    "braceright": [[0x0b, "altgr"], [0x1b, "shift"]],
    "degree": [0x0b, "shift", "altgr"],
    "minus": [0x0c],
    "underscore": [0x0c, "shift"],
    "backslash": [[0x0c, "altgr"], [0x2b]],
    "questiondown": [0x0c, "shift", "altgr"],
    "equal": [0x0d],
    "plus": [0x0d, "shift"],
    "dead_cedilla": [0x0d, "altgr"],
    "dead_ogonek": [0x0d, "shift", "altgr"],
    "Greek_OMEGA": [0x10, "shift", "altgr"],
    "lstroke": [0x11, "altgr"],
    "Lstroke": [0x11, "shift", "altgr"],
    "emacron": [0x12, "altgr"],
    "Emacron": [0x12, "shift", "altgr"],
    "rcedilla": [0x13, "altgr"],
    "Rcedilla": [0x13, "shift", "altgr"],
    "tslash": [0x14, "altgr"],
    "Tslash": [0x14, "shift", "altgr"],
    "leftarrow": [0x15, "altgr"],
    "yen": [0x15, "shift", "altgr"],
    "umacron": [0x16, "altgr"],
    "Umacron": [0x16, "shift", "altgr"],
    "imacron": [0x17, "altgr"],
    "Imacron": [0x17, "shift", "altgr"],
    "omacron": [0x18, "altgr"],
    "Omacron": [0x18, "shift", "altgr"],
    "thorn": [0x19, "altgr"],
    "THORN": [0x19, "shift", "altgr"],
    "dead_diaeresis": [0x1a, "altgr"],
    "dead_abovering": [0x1a, "shift", "altgr"],
    "dead_tilde": [0x1b, "altgr"],
    "dead_macron": [0x1b, "shift", "altgr"],
    "ISO_Next_Group": [0x1c, "shift"],
    "amacron": [0x1e, "altgr"],
    "Amacron": [0x1e, "shift", "altgr"],
    "scaron": [0x1f, "altgr"],
    "Scaron": [0x1f, "shift", "altgr"],
    "eth": [0x20, "altgr"],
    "ETH": [0x20, "shift", "altgr"],
    "dstroke": [0x21, "altgr"],
    "ordfeminine": [0x21, "shift", "altgr"],
    "gcedilla": [0x22, "altgr"],
    "Gcedilla": [0x22, "shift", "altgr"],
    "hstroke": [0x23, "altgr"],
    "Hstroke": [0x23, "shift", "altgr"],
    "kcedilla": [0x25, "altgr"],
    "Kcedilla": [0x25, "shift", "altgr"],
    "lcedilla": [0x26, "altgr"],
    "Lcedilla": [0x26, "shift", "altgr"],
    "semicolon": [0x27],
    "colon": [0x27, "shift"],
    "dead_acute": [0x27, "altgr"],
    "dead_doubleacute": [0x27, "shift", "altgr"],
    "apostrophe": [[0x28], [0x30, "shift", "altgr"]],
    "quotedbl": [0x28, "shift"],
    "leftdoublequotemark": [[0x28, "altgr"], [0x2f, "altgr"]],
    "doublelowquotemark": [0x28, "shift", "altgr"],
    "grave": [[0x29], [0x2f, "shift", "altgr"]],
    "asciitilde": [0x29, "shift"],
    "notsign": [0x29, "altgr"],
    "bar": [0x2b, "shift"],
    "dead_grave": [0x2b, "altgr"],
    "dead_breve": [0x2b, "shift", "altgr"],
    "zcaron": [0x2c, "altgr"],
    "Zcaron": [0x2c, "shift", "altgr"],
    "guillemotright": [0x2d, "altgr"],
    "greater": [[0x2d, "shift", "altgr"], [0x34, "shift"]],
    "ccaron": [0x2e, "altgr"],
    "Ccaron": [0x2e, "shift", "altgr"],
    "rightdoublequotemark": [0x30, "altgr"],
    "ncedilla": [0x31, "altgr"],
    "Ncedilla": [0x31, "shift", "altgr"],
    "mu": [0x32, "altgr"],
    "masculine": [0x32, "shift", "altgr"],
    "comma": [0x33],
    "less": [0x33, "shift"],
    "horizconnector": [0x33, "altgr"],
    "multiply": [0x33, "shift", "altgr"],
    "period": [0x34],
    "periodcentered": [0x34, "altgr"],
    "division": [0x34, "shift", "altgr"],
    "slash": [0x35],
    "question": [0x35, "shift"],
    "dead_belowdot": [0x35, "altgr"],
    "dead_abovedot": [0x35, "shift", "altgr"],
    "nobreakspace": [0x39, "altgr"]
  },
  "mk": {
    "map": [0x42f],
    "exclam": [0x02, "shift"],
    "at": [0x03, "shift"],
    "doublelowquotemark": [0x03, "shift", "altgr"],
    "numbersign": [0x04, "shift"],
    "leftdoublequotemark": [0x04, "shift", "altgr"],
    "dollar": [0x05, "shift"],
    "percent": [0x06, "shift"],
    "asciicircum": [0x07, "shift"],
    "ampersand": [0x08, "shift"],
    "asterisk": [0x09, "shift"],
    "parenleft": [0x0a, "shift"],
    "parenright": [0x0b, "shift"],
    "minus": [0x0c],
    "underscore": [0x0c, "shift"],
    "equal": [0x0d],
    "plus": [0x0d, "shift"],
    "Cyrillic_lje": [0x10, "altgr"],
    "Cyrillic_LJE": [0x10, "shift", "altgr"],
    "Cyrillic_nje": [0x11, "altgr"],
    "Cyrillic_NJE": [0x11, "shift", "altgr"],
    "Cyrillic_ie": [0x12, "altgr"],
    "Cyrillic_IE": [0x12, "shift", "altgr"],
    "Cyrillic_er": [0x13, "altgr"],
    "Cyrillic_ER": [0x13, "shift", "altgr"],
    "Cyrillic_te": [0x14, "altgr"],
    "Cyrillic_TE": [0x14, "shift", "altgr"],
    "Macedonia_dse": [0x15, "altgr"],
    "Macedonia_DSE": [0x15, "shift", "altgr"],
    "Cyrillic_u": [0x16, "altgr"],
    "Cyrillic_U": [0x16, "shift", "altgr"],
    "Cyrillic_i": [0x17, "altgr"],
    "Cyrillic_I": [0x17, "shift", "altgr"],
    "Cyrillic_o": [0x18, "altgr"],
    "Cyrillic_O": [0x18, "shift", "altgr"],
    "Cyrillic_pe": [0x19, "altgr"],
    "Cyrillic_PE": [0x19, "shift", "altgr"],
    "bracketleft": [0x1a],
    "braceleft": [0x1a, "shift"],
    "Cyrillic_sha": [0x1a, "altgr"],
    "Cyrillic_SHA": [0x1a, "shift", "altgr"],
    "bracketright": [0x1b],
    "braceright": [0x1b, "shift"],
    "Macedonia_gje": [0x1b, "altgr"],
    "Macedonia_GJE": [0x1b, "shift", "altgr"],
    "Cyrillic_a": [0x1e, "altgr"],
    "Cyrillic_A": [0x1e, "shift", "altgr"],
    "Cyrillic_es": [0x1f, "altgr"],
    "Cyrillic_ES": [0x1f, "shift", "altgr"],
    "Cyrillic_de": [0x20, "altgr"],
    "Cyrillic_DE": [0x20, "shift", "altgr"],
    "Cyrillic_ef": [0x21, "altgr"],
    "Cyrillic_EF": [0x21, "shift", "altgr"],
    "Cyrillic_ghe": [0x22, "altgr"],
    "Cyrillic_GHE": [0x22, "shift", "altgr"],
    "Cyrillic_ha": [0x23, "altgr"],
    "Cyrillic_HA": [0x23, "shift", "altgr"],
    "Cyrillic_je": [0x24, "altgr"],
    "Cyrillic_JE": [0x24, "shift", "altgr"],
    "Cyrillic_ka": [0x25, "altgr"],
    "Cyrillic_KA": [0x25, "shift", "altgr"],
    "Cyrillic_el": [0x26, "altgr"],
    "Cyrillic_EL": [0x26, "shift", "altgr"],
    "semicolon": [[0x27], [0x33, "shift", "altgr"]],
    "colon": [[0x27, "shift"], [0x34, "shift", "altgr"]],
    "Cyrillic_che": [0x27, "altgr"],
    "Cyrillic_CHE": [0x27, "shift", "altgr"],
    "apostrophe": [0x28],
    "quotedbl": [0x28, "shift"],
    "Macedonia_kje": [0x28, "altgr"],
    "Macedonia_KJE": [0x28, "shift", "altgr"],
    "grave": [0x29],
    "asciitilde": [0x29, "shift"],
    "backslash": [0x2b],
    "bar": [0x2b, "shift"],
    "Cyrillic_zhe": [0x2b, "altgr"],
    "Cyrillic_ZHE": [0x2b, "shift", "altgr"],
    "Cyrillic_ze": [0x2c, "altgr"],
    "Cyrillic_ZE": [0x2c, "shift", "altgr"],
    "Cyrillic_dzhe": [0x2d, "altgr"],
    "Cyrillic_DZHE": [0x2d, "shift", "altgr"],
    "Cyrillic_tse": [0x2e, "altgr"],
    "Cyrillic_TSE": [0x2e, "shift", "altgr"],
    "Cyrillic_ve": [0x2f, "altgr"],
    "Cyrillic_VE": [0x2f, "shift", "altgr"],
    "Cyrillic_be": [0x30, "altgr"],
    "Cyrillic_BE": [0x30, "shift", "altgr"],
    "Cyrillic_en": [0x31, "altgr"],
    "Cyrillic_EN": [0x31, "shift", "altgr"],
    "Cyrillic_em": [0x32, "altgr"],
    "Cyrillic_EM": [0x32, "shift", "altgr"],
    "comma": [0x33],
    "less": [0x33, "shift"],
    "period": [0x34],
    "greater": [0x34, "shift"],
    "slash": [0x35],
    "question": [0x35, "shift"]
  },
  "nl": {
    "map": [0x413],
    "exclam": [0x02, "shift"],
    "onesuperior": [0x02, "altgr"],
    "quotebl": [0x03, "shift"],
    "twosuperior": [0x03, "altgr"],
    "numbersign": [0x04, "shift"],
    "threesuperior": [0x04, "altgr"],
    "dollar": [0x05, "shift"],
    "onequarter": [0x05, "altgr"],
    "percent": [0x06, "shift"],
    "onehalf": [0x06, "altgr"],
    "ampersand": [0x07, "shift"],
    "threequarters": [0x07, "altgr"],
    "underscore": [0x08, "shift"],
    "sterling": [0x08, "altgr"],
    "parenleft": [0x09, "shift"],
    "braceleft": [0x09, "altgr"],
    "parenright": [0x0a, "shift"],
    "braceright": [0x0a, "altgr"],
    "apostrophe": [0x0b, "shift"],
    "slash": [0x0c],
    "question": [0x0c, "shift"],
    "backslash": [0x0c, "altgr"],
    "degree": [0x0d],
    "dead_tilde": [0x0d, "shift"],
    "dead_cedilla": [0x0d, "altgr"],
    "EuroSign": [0x12, "altgr"],
    "paragraph": [0x13, "altgr"],
    "dead_diaeresis": [0x1a],
    "dead_circumflex": [0x1a, "shift"],
    "asterisk": [0x1b],
    "bar": [0x1b, "shift"],
    "ssharp": [0x1f, "altgr"],
    "plus": [0x27],
    "plusminus": [0x27, "shift"],
    "dead_acute": [0x28],
    "dead_grave": [0x28, "shift"],
    "at": [0x29],
    "section": [0x29, "shift"],
    "notsign": [0x29, "altgr"],
    "less": [0x2b],
    "greater": [0x2b, "shift"],
    "guillemotleft": [0x2c, "altgr"],
    "guillemotright": [0x2d, "altgr"],
    "copyright": [0x2e, "altgr"],
    "mu": [0x32, "altgr"],
    "comma": [0x33],
    "semicolon": [0x33, "shift"],
    "period": [0x34],
    "colon": [0x34, "shift"],
    "periodcentered": [0x34, "altgr"],
    "hyphen": [0x35],
    "equal": [0x35, "shift"],
    "bracketright": [0x56],
    "bracketleft": [0x56, "shift"],
    "brokenbar": [0x56, "altgr"]
  },
  "nl-be": {
    "map": [0x813]
  },
  "no": {
    "map": [0x414],
    "exclam": [0x02, "shift"],
    "exclamdown": [0x02, "altgr"],
    "onesuperior": [0x02, "shift", "altgr"],
    "quotedbl": [0x03, "shift"],
    "at": [0x03, "altgr"],
    "twosuperior": [0x03, "shift", "altgr"],
    "numbersign": [0x04, "shift"],
    "sterling": [0x04, "altgr"],
    "threesuperior": [0x04, "shift", "altgr"],
    "currency": [0x05, "shift"],
    "dollar": [0x05, "altgr"],
    "onequarter": [0x05, "shift", "altgr"],
    "percent": [0x06, "shift"],
    "onehalf": [[0x06, "altgr"], [0x56, "altgr"]],
    "cent": [[0x06, "shift", "altgr"], [0x12, "shift", "altgr"]],
    "ampersand": [0x07, "shift"],
    "yen": [[0x07, "altgr"], [0x15, "shift", "altgr"]],
    "fiveeighths": [0x07, "shift", "altgr"],
    "slash": [0x08, "shift"],
    "braceleft": [0x08, "altgr"],
    "division": [0x08, "shift", "altgr"],
    "parenleft": [0x09, "shift"],
    "bracketleft": [0x09, "altgr"],
    "guillemotleft": [[0x09, "shift", "altgr"], [0x2c, "altgr"]],
    "parenright": [0x0a, "shift"],
    "bracketright": [0x0a, "altgr"],
    "guillemotright": [[0x0a, "shift", "altgr"], [0x2d, "altgr"]],
    "equal": [0x0b, "shift"],
    "braceright": [0x0b, "altgr"],
    "degree": [0x0b, "shift", "altgr"],
    "plus": [0x0c],
    "question": [0x0c, "shift"],
    "plusminus": [0x0c, "altgr"],
    "questiondown": [0x0c, "shift", "altgr"],
    "backslash": [0x0d],
    "dead_grave": [0x0d, "shift"],
    "dead_acute": [0x0d, "altgr"],
    "notsign": [0x0d, "shift", "altgr"],
    "Greek_OMEGA": [0x10, "shift", "altgr"],
    "lstroke": [[0x11, "altgr"], [0x26, "altgr"]],
    "Lstroke": [[0x11, "shift", "altgr"], [0x26, "shift", "altgr"]],
    "EuroSign": [0x12, "altgr"],
    "registered": [0x13, "altgr"],
    "thorn": [[0x14, "altgr"], [0x19, "altgr"]],
    "THORN": [[0x14, "shift", "altgr"], [0x19, "shift", "altgr"]],
    "leftarrow": [0x15, "altgr"],
    "downarrow": [0x16, "altgr"],
    "uparrow": [0x16, "shift", "altgr"],
    "rightarrow": [0x17, "altgr"],
    "idotless": [0x17, "shift", "altgr"],
    "oe": [0x18, "altgr"],
    "OE": [0x18, "shift", "altgr"],
    "aring": [0x1a],
    "Aring": [0x1a, "shift"],
    "dead_diaeresis": [[0x1a, "altgr"], [0x1b]],
    "dead_abovering": [0x1a, "shift", "altgr"],
    "dead_circumflex": [0x1b, "shift"],
    "asciicircum": [0x01b, "shift"],
    "dead_tilde": [0x1b, "altgr"],
    "asciitilde": [0x1b, "altgr"],
    "dead_caron": [[0x1b, "shift", "altgr"], [0x28, "shift", "altgr"]],
    "ordfeminine": [[0x1e, "altgr"], [0x21, "shift", "altgr"]],
    "masculine": [[0x1e, "shift", "altgr"], [0x32, "shift", "altgr"]],
    "ssharp": [0x1f, "altgr"],
    "section": [[0x1f, "shift", "altgr"], [0x29, "shift"]],
    "eth": [0x20, "altgr"],
    "ETH": [0x20, "shift", "altgr"],
    "dstroke": [0x21, "altgr"],
    "eng": [0x22, "altgr"],
    "ENG": [0x22, "shift", "altgr"],
    "hstroke": [0x23, "altgr"],
    "Hstroke": [0x23, "shift", "altgr"],
    "kra": [0x25, "altgr"],
    "oslash": [0x27],
    "Ooblique": [0x27, "shift"],
    "dead_doubleacute": [0x27, "shift", "altgr"],
    "ae": [0x28],
    "AE": [0x28, "shift"],
    "bar": [0x29],
    "brokenbar": [0x29, "altgr"],
    "paragraph": [0x29, "shift", "altgr"],
    "apostrophe": [0x2b],
    "asterisk": [0x2b, "shift"],
    "multiply": [0x2b, "shift", "altgr"],
    "copyright": [0x2e, "altgr"],
    "leftdoublequotemark": [0x2f, "altgr"],
    "rightdoublequotemark": [0x30, "altgr"],
    "mu": [0x32, "altgr"],
    "comma": [0x33],
    "semicolon": [0x33, "shift"],
    "dead_cedilla": [0x33, "altgr"],
    "dead_ogonek": [0x33, "shift", "altgr"],
    "period": [0x34],
    "colon": [0x34, "shift"],
    "periodcentered": [0x34, "altgr"],
    "dead_abovedot": [0x34, "shift", "altgr"],
    "minus": [0x35],
    "underscore": [0x35, "shift"],
    "hyphen": [0x35, "altgr"],
    "macron": [0x35, "shift", "altgr"],
    "nobreakspace": [0x39, "altgr"],
    "threequarters": [0x56, "shift", "altgr"]
  },
  "pl": {
    "map": [0x415],
    "exclam": [0x02, "shift"],
    "onesuperior": [0x02, "altgr"],
    "exclamdown": [0x02, "shift", "altgr"],
    "at": [0x03, "shift"],
    "twosuperior": [0x03, "altgr"],
    "oneeighth": [0x03, "shift", "altgr"],
    "numbersign": [0x04, "shift"],
    "threesuperior": [0x04, "altgr"],
    "sterling": [0x04, "shift", "altgr"],
    "dollar": [0x05, "shift"],
    "onequarter": [0x05, "altgr"],
    "percent": [0x06, "shift"],
    "onehalf": [0x06, "altgr"],
    "threeeighths": [0x06, "shift", "altgr"],
    "asciicircum": [0x07, "shift"],
    "threequarters": [0x07, "altgr"],
    "fiveeighths": [0x07, "shift", "altgr"],
    "ampersand": [0x08, "shift"],
    "braceleft": [[0x08, "altgr"], [0x1a, "shift"]],
    "seveneighths": [0x08, "shift", "altgr"],
    "asterisk": [0x09, "shift"],
    "bracketleft": [[0x09, "altgr"], [0x1a]],
    "trademark": [0x09, "shift", "altgr"],
    "parenleft": [0x0a, "shift"],
    "bracketright": [[0x0a, "altgr"], [0x1b]],
    "plusminus": [0x0a, "shift", "altgr"],
    "parenright": [0x0b, "shift"],
    "braceright": [[0x0b, "altgr"], [0x1b, "shift"]],
    "degree": [0x0b, "shift", "altgr"],
    "minus": [0x0c],
    "underscore": [0x0c, "shift"],
    "backslash": [[0x0c, "altgr"], [0x2b]],
    "questiondown": [0x0c, "shift", "altgr"],
    "equal": [0x0d],
    "plus": [0x0d, "shift"],
    "dead_cedilla": [0x0d, "altgr"],
    "dead_ogonek": [0x0d, "shift", "altgr"],
    "Greek_OMEGA": [0x10, "shift", "altgr"],
    "lstroke": [[0x11, "altgr"], [0x26, "altgr"]],
    "Lstroke": [[0x11, "shift", "altgr"], [0x26, "shift", "altgr"]],
    "eogonek": [0x12, "altgr"],
    "Eogonek": [0x12, "shift", "altgr"],
    "paragraph": [0x13, "altgr"],
    "registered": [0x13, "shift", "altgr"],
    "tslash": [0x14, "altgr"],
    "Tslash": [0x14, "shift", "altgr"],
    "leftarrow": [0x15, "altgr"],
    "yen": [0x15, "shift", "altgr"],
    "EuroSign": [0x16, "altgr"],
    "uparrow": [0x16, "shift", "altgr"],
    "rightarrow": [0x17, "altgr"],
    "idotless": [0x17, "shift", "altgr"],
    "oacute": [0x18, "altgr"],
    "Oacute": [0x18, "shift", "altgr"],
    "thorn": [0x19, "altgr"],
    "THORN": [0x19, "shift", "altgr"],
    "dead_diaeresis": [0x1a, "altgr"],
    "dead_abovering": [0x1a, "shift", "altgr"],
    "dead_tilde": [0x1b, "altgr"],
    "dead_macron": [0x1b, "shift", "altgr"],
    "aogonek": [0x1e, "altgr"],
    "Aogonek": [0x1e, "shift", "altgr"],
    "sacute": [0x1f, "altgr"],
    "Sacute": [0x1f, "shift", "altgr"],
    "eth": [0x20, "altgr"],
    "ETH": [0x20, "shift", "altgr"],
    "dstroke": [0x21, "altgr"],
    "ordfeminine": [0x21, "shift", "altgr"],
    "eng": [0x22, "altgr"],
    "ENG": [0x22, "shift", "altgr"],
    "hstroke": [0x23, "altgr"],
    "Hstroke": [0x23, "shift", "altgr"],
    "kra": [0x25, "altgr"],
    "semicolon": [0x27],
    "colon": [0x27, "shift"],
    "dead_acute": [0x27, "altgr"],
    "dead_doubleacute": [0x27, "shift", "altgr"],
    "apostrophe": [0x28],
    "quotedbl": [0x28, "shift"],
    "dead_circumflex": [0x28, "altgr"],
    "dead_caron": [0x28, "shift", "altgr"],
    "grave": [[0x29], [0x2f, "shift", "altgr"]],
    "asciitilde": [0x29, "shift"],
    "notsign": [0x29, "altgr"],
    "bar": [0x2b, "shift"],
    "dead_grave": [0x2b, "altgr"],
    "dead_breve": [0x2b, "shift", "altgr"],
    "zabovedot": [0x2c, "altgr"],
    "Zabovedot": [0x2c, "shift", "altgr"],
    "zacute": [0x2d, "altgr"],
    "Zacute": [0x2d, "shift", "altgr"],
    "cacute": [0x2e, "altgr"],
    "Cacute": [0x2e, "shift", "altgr"],
    "leftdoublequotemark": [0x2f, "altgr"],
    "rightdoublequotemark": [0x30, "altgr"],
    "nacute": [0x31, "altgr"],
    "Nacute": [0x31, "shift", "altgr"],
    "mu": [0x32, "altgr"],
    "masculine": [0x32, "shift", "altgr"],
    "comma": [0x33],
    "less": [0x33, "shift"],
    "horizconnector": [0x33, "altgr"],
    "multiply": [0x33, "shift", "altgr"],
    "period": [0x34],
    "greater": [0x34, "shift"],
    "periodcentered": [0x34, "altgr"],
    "division": [0x34, "shift", "altgr"],
    "slash": [0x35],
    "question": [0x35, "shift"],
    "dead_belowdot": [0x35, "altgr"],
    "dead_abovedot": [0x35, "shift", "altgr"]
  },
  "pt": {
    "map": [0x816],
    "exclam": [0x02, "shift"],
    "onesuperior": [0x02, "altgr"],
    "exclamdown": [0x02, "shift", "altgr"],
    "quotedbl": [0x03, "shift"],
    "at": [0x03, "altgr"],
    "oneeighth": [0x03, "shift", "altgr"],
    "numbersign": [0x04, "shift"],
    "sterling": [0x04, "altgr"],
    "dollar": [0x05, "shift"],
    "section": [0x05, "altgr"],
    "percent": [0x06, "shift"],
    "onehalf": [0x06, "altgr"],
    "threeeighths": [0x06, "shift", "altgr"],
    "ampersand": [0x07, "shift"],
    "threequarters": [0x07, "altgr"],
    "fiveeighths": [0x07, "shift", "altgr"],
    "slash": [0x08, "shift"],
    "braceleft": [0x08, "altgr"],
    "seveneighths": [0x08, "shift", "altgr"],
    "parenleft": [0x09, "shift"],
    "bracketleft": [0x09, "altgr"],
    "trademark": [0x09, "shift", "altgr"],
    "parenright": [0x0a, "shift"],
    "bracketright": [0x0a, "altgr"],
    "plusminus": [0x0a, "shift", "altgr"],
    "equal": [0x0b, "shift"],
    "braceright": [0x0b, "altgr"],
    "degree": [0x0b, "shift", "altgr"],
    "apostrophe": [0x0c],
    "question": [0x0c, "shift"],
    "backslash": [[0x0c, "altgr"], [0x29]],
    "questiondown": [0x0c, "shift", "altgr"],
    "guillemotleft": [0x0d],
    "guillemotright": [0x0d, "shift"],
    "dead_cedilla": [0x0d, "altgr"],
    "dead_ogonek": [0x0d, "shift", "altgr"],
    "Greek_OMEGA": [0x10, "shift", "altgr"],
    "lstroke": [[0x11, "altgr"], [0x26, "altgr"]],
    "Lstroke": [[0x11, "shift", "altgr"], [0x26, "shift", "altgr"]],
    "EuroSign": [0x12, "altgr"],
    "cent": [[0x12, "shift", "altgr"], [0x2e, "altgr"]],
    "paragraph": [0x13, "altgr"],
    "registered": [0x13, "shift", "altgr"],
    "tslash": [0x14, "altgr"],
    "Tslash": [0x14, "shift", "altgr"],
    "leftarrow": [0x15, "altgr"],
    "yen": [0x15, "shift", "altgr"],
    "downarrow": [0x16, "altgr"],
    "uparrow": [0x16, "shift", "altgr"],
    "rightarrow": [0x17, "altgr"],
    "idotless": [0x17, "shift", "altgr"],
    "oslash": [0x18, "altgr"],
    "Ooblique": [0x18, "shift", "altgr"],
    "thorn": [0x19, "altgr"],
    "THORN": [0x19, "shift", "altgr"],
    "plus": [0x1a],
    "asterisk": [0x1a, "shift"],
    "dead_diaeresis": [0x1a, "altgr"],
    "dead_abovering": [0x1a, "shift", "altgr"],
    "dead_acute": [0x1b],
    "dead_grave": [0x1b, "shift"],
    "dead_tilde": [[0x1b, "altgr"], [0x2b]],
    "dead_macron": [0x1b, "shift", "altgr"],
    "ae": [0x1e, "altgr"],
    "AE": [0x1e, "shift", "altgr"],
    "ssharp": [0x1f, "altgr"],
    "eth": [0x20, "altgr"],
    "ETH": [0x20, "shift", "altgr"],
    "dstroke": [0x21, "altgr"],
    "ordfeminine": [[0x21, "shift", "altgr"], [0x28, "shift"]],
    "eng": [0x22, "altgr"],
    "ENG": [0x22, "shift", "altgr"],
    "hstroke": [0x23, "altgr"],
    "Hstroke": [0x23, "shift", "altgr"],
    "kra": [0x25, "altgr"],
    "ccedilla": [0x27],
    "Ccedilla": [0x27, "shift"],
    "dead_doubleacute": [0x27, "shift", "altgr"],
    "masculine": [0x28],
    "dead_circumflex": [[0x28, "altgr"], [0x2b, "shift"]],
    "dead_caron": [0x28, "shift", "altgr"],
    "bar": [0x29, "shift"],
    "notsign": [0x29, "altgr"],
    "dead_breve": [0x2b, "shift", "altgr"],
    "less": [0x56],
    "greater": [0x56, "shift"],
    "copyright": [0x2e, "shift", "altgr"],
    "leftdoublequotemark": [0x2f, "altgr"],
    "grave": [0x2f, "shift", "altgr"],
    "rightdoublequotemark": [0x30, "altgr"],
    "mu": [0x32, "altgr"],
    "comma": [0x33],
    "semicolon": [0x33, "shift"],
    "horizconnector": [0x33, "altgr"],
    "multiply": [0x33, "shift", "altgr"],
    "period": [0x34],
    "colon": [0x34, "shift"],
    "periodcentered": [0x34, "altgr"],
    "division": [0x34, "shift", "altgr"],
    "minus": [0x35],
    "underscore": [0x35, "shift"],
    "dead_belowdot": [0x35, "altgr"],
    "dead_abovedot": [0x35, "shift", "altgr"]
  },
  "pt-br": {
    "map": [0x416],
    "exclam": [0x02, "shift"],
    "onesuperior": [0x02, "altgr"],
    "exclamdown": [0x02, "shift", "altgr"],
    "at": [0x03, "shift"],
    "twosuperior": [0x03, "altgr"],
    "onehalf": [0x03, "shift", "altgr"],
    "numbersign": [0x04, "shift"],
    "threesuperior": [0x04, "altgr"],
    "threequarters": [0x04, "shift", "altgr"],
    "dollar": [0x05, "shift"],
    "sterling": [0x05, "altgr"],
    "onequarter": [0x05, "shift", "altgr"],
    "percent": [0x06, "shift"],
    "cent": [0x06, "altgr"],
    "dead_diaeresis": [0x07, "shift"],
    "notsign": [0x07, "altgr"],
    "diaeresis": [0x07, "shift", "altgr"],
    "ampersand": [0x08, "shift"],
    "braceleft": [[0x08, "altgr"], [0x1b, "shift"]],
    "asterisk": [0x09, "shift"],
    "bracketleft": [[0x09, "altgr"], [0x1b]],
    "parenleft": [0x0a, "shift"],
    "bracketright": [[0x0a, "altgr"], [0x2b]],
    "parenright": [0x0b, "shift"],
    "braceright": [[0x0b, "altgr"], [0x2b, "shift"]],
    "minus": [0x0c],
    "underscore": [0x0c, "shift"],
    "backslash": [[0x0c, "altgr"], [0x56]],
    "equal": [0x0d],
    "plus": [0x0d, "shift"],
    "section": [0x0d, "altgr"],
    "EuroSign": [0x12, "altgr"],
    "registered": [0x13, "altgr"],
    "dead_acute": [0x1a],
    "dead_grave": [0x1a, "shift"],
    "acute": [0x1a, "altgr"],
    "grave": [0x1a, "shift", "altgr"],
    "ordfeminine": [0x1b, "altgr"],
    "ccedilla": [0x27],
    "Ccedilla": [0x27, "shift"],
    "dead_tilde": [0x28],
    "dead_circumflex": [0x28, "shift"],
    "asciitilde": [0x28, "altgr"],
    "asciicircum": [0x28, "shift", "altgr"],
    "apostrophe": [0x29],
    "quotedbl": [0x29, "shift"],
    "masculine": [0x2b, "altgr"],
    "copyright": [0x2e, "altgr"],
    "mu": [0x32, "altgr"],
    "comma": [[0x33], [0x53, "numlock"]],
    "less": [0x33, "shift"],
    "period": [0x34],
    "greater": [0x34, "shift"],
    "semicolon": [0x35],
    "colon": [0x35, "shift"],
    "bar": [0x56, "shift"],
    "slash": [0x73],
    "question": [0x73, "shift"],
    "degree": [0x73, "altgr"],
    "KP_Decimal": [0x34]
  },
  "ru": {
    "map": [0x419],
    "exclam": [0x02, "shift"],
    "at": [0x03, "shift"],
    "quotedbl": [[0x03, "shift", "altgr"], [0x28, "shift"]],
    "numerosign": [0x04, "shift"],
    "dollar": [0x05, "shift"],
    "asterisk": [[0x05, "shift", "altgr"], [0x09, "shift"]],
    "percent": [0x06, "shift"],
    "colon": [[0x06, "shift", "altgr"], [0x27, "shift"]],
    "asciicircum": [0x07, "shift"],
    "comma": [[0x07, "shift", "altgr"], [0x33]],
    "ampersand": [0x08, "shift"],
    "period": [[0x08, "shift", "altgr"], [0x34]],
    "semicolon": [[0x09, "shift", "altgr"], [0x27]],
    "parenleft": [0x0a, "shift"],
    "parenright": [0x0b, "shift"],
    "minus": [0x0c],
    "underscore": [0x0c, "shift"],
    "equal": [0x0d],
    "plus": [0x0d, "shift"],
    "Cyrillic_shorti": [0x10, "altgr"],
    "Cyrillic_SHORTI": [0x10, "shift", "altgr"],
    "Cyrillic_tse": [0x11, "altgr"],
    "Cyrillic_TSE": [0x11, "shift", "altgr"],
    "Cyrillic_u": [0x12, "altgr"],
    "Cyrillic_U": [0x12, "shift", "altgr"],
    "Cyrillic_ka": [0x13, "altgr"],
    "Cyrillic_KA": [0x13, "shift", "altgr"],
    "Cyrillic_ie": [0x14, "altgr"],
    "Cyrillic_IE": [0x14, "shift", "altgr"],
    "Cyrillic_en": [0x15, "altgr"],
    "Cyrillic_EN": [0x15, "shift", "altgr"],
    "Cyrillic_ghe": [0x16, "altgr"],
    "Cyrillic_GHE": [0x16, "shift", "altgr"],
    "Cyrillic_sha": [0x17, "altgr"],
    "Cyrillic_SHA": [0x17, "shift", "altgr"],
    "Cyrillic_shcha": [0x18, "altgr"],
    "Cyrillic_SHCHA": [0x18, "shift", "altgr"],
    "Cyrillic_ze": [0x19, "altgr"],
    "Cyrillic_ZE": [0x19, "shift", "altgr"],
    "bracketleft": [0x1a],
    "braceleft": [0x1a, "shift"],
    "Cyrillic_ha": [0x1a, "altgr"],
    "Cyrillic_HA": [0x1a, "shift", "altgr"],
    "bracketright": [0x1b],
    "braceright": [0x1b, "shift"],
    "Cyrillic_hardsign": [0x1b, "altgr"],
    "Cyrillic_HARDSIGN": [0x1b, "shift", "altgr"],
    "Cyrillic_ef": [0x1e, "altgr"],
    "Cyrillic_EF": [0x1e, "shift", "altgr"],
    "Cyrillic_yeru": [0x1f, "altgr"],
    "Cyrillic_YERU": [0x1f, "shift", "altgr"],
    "Cyrillic_ve": [0x20, "altgr"],
    "Cyrillic_VE": [0x20, "shift", "altgr"],
    "Cyrillic_a": [0x21, "altgr"],
    "Cyrillic_A": [0x21, "shift", "altgr"],
    "Cyrillic_pe": [0x22, "altgr"],
    "Cyrillic_PE": [0x22, "shift", "altgr"],
    "Cyrillic_er": [0x23, "altgr"],
    "Cyrillic_ER": [0x23, "shift", "altgr"],
    "Cyrillic_o": [0x24, "altgr"],
    "Cyrillic_O": [0x24, "shift", "altgr"],
    "Cyrillic_el": [0x25, "altgr"],
    "Cyrillic_EL": [0x25, "shift", "altgr"],
    "Cyrillic_de": [0x26, "altgr"],
    "Cyrillic_DE": [0x26, "shift", "altgr"],
    "Cyrillic_zhe": [0x27, "altgr"],
    "Cyrillic_ZHE": [0x27, "shift", "altgr"],
    "apostrophe": [0x28],
    "Cyrillic_e": [0x28, "altgr"],
    "Cyrillic_E": [0x28, "shift", "altgr"],
    "grave": [0x29],
    "asciitilde": [0x29, "shift"],
    "Cyrillic_io": [0x29, "altgr"],
    "Cyrillic_IO": [0x29, "shift", "altgr"],
    "backslash": [0x2b],
    "bar": [[0x2b, "shift"], [0x56, "shift", "altgr"]],
    "Cyrillic_ya": [0x2c, "altgr"],
    "Cyrillic_YA": [0x2c, "shift", "altgr"],
    "Cyrillic_che": [0x2d, "altgr"],
    "Cyrillic_CHE": [0x2d, "shift", "altgr"],
    "Cyrillic_es": [0x2e, "altgr"],
    "Cyrillic_ES": [0x2e, "shift", "altgr"],
    "Cyrillic_em": [0x2f, "altgr"],
    "Cyrillic_EM": [0x2f, "shift", "altgr"],
    "Cyrillic_i": [0x30, "altgr"],
    "Cyrillic_I": [0x30, "shift", "altgr"],
    "Cyrillic_te": [0x31, "altgr"],
    "Cyrillic_TE": [0x31, "shift", "altgr"],
    "Cyrillic_softsign": [0x32, "altgr"],
    "Cyrillic_SOFTSIGN": [0x32, "shift", "altgr"],
    "less": [0x33, "shift"],
    "Cyrillic_be": [0x33, "altgr"],
    "Cyrillic_BE": [0x33, "shift", "altgr"],
    "greater": [0x34, "shift"],
    "Cyrillic_yu": [0x34, "altgr"],
    "Cyrillic_YU": [0x34, "shift", "altgr"],
    "slash": [[0x35], [0x56, "altgr"]],
    "question": [0x35, "shift"]
  },
  "sl": {
    "map": [0x424],
    "exclam": [0x02, "shift"],
    "asciitilde": [0x02, "altgr"],
    "dead_tilde": [0x02, "shift", "altgr"],
    "quotedbl": [0x03, "shift"],
    "dead_caron": [0x03, "altgr"],
    "caron": [0x03, "shift", "altgr"],
    "numbersign": [0x04, "shift"],
    "asciicircum": [0x04, "altgr"],
    "dead_circumflex": [0x04, "shift", "altgr"],
    "dollar": [0x05, "shift"],
    "dead_breve": [0x05, "altgr"],
    "breve": [0x05, "shift", "altgr"],
    "percent": [0x06, "shift"],
    "degree": [0x06, "altgr"],
    "dead_abovering": [0x06, "shift", "altgr"],
    "ampersand": [0x07, "shift"],
    "dead_ogonek": [0x07, "altgr"],
    "ogonek": [0x07, "shift", "altgr"],
    "slash": [0x08, "shift"],
    "grave": [0x08, "altgr"],
    "dead_grave": [0x08, "shift", "altgr"],
    "parenleft": [0x09, "shift"],
    "dead_abovedot": [0x09, "altgr"],
    "abovedot": [0x09, "shift", "altgr"],
    "parenright": [0x0a, "shift"],
    "dead_acute": [0x0a, "altgr"],
    "equal": [0x0b, "shift"],
    "dead_doubleacute": [0x0b, "altgr"],
    "doubleacute": [0x0b, "shift", "altgr"],
    "apostrophe": [0x0c],
    "question": [0x0c, "shift"],
    "dead_diaeresis": [0x0c, "altgr"],
    "diaeresis": [0x0c, "shift", "altgr"],
    "plus": [0x0d],
    "asterisk": [0x0d, "shift"],
    "dead_cedilla": [[0x0d, "altgr"], [0x29]],
    "cedilla": [0x0d, "shift", "altgr"],
    "backslash": [0x10, "altgr"],
    "Greek_OMEGA": [0x10, "shift", "altgr"],
    "bar": [0x11, "altgr"],
    "Lstroke": [[0x11, "shift", "altgr"], [0x26, "altgr"]],
    "EuroSign": [0x12, "altgr"],
    "paragraph": [0x13, "altgr"],
    "registered": [0x13, "shift", "altgr"],
    "tslash": [0x14, "altgr"],
    "Tslash": [0x14, "shift", "altgr"],
    "z": [0x15],
    "leftarrow": [0x15, "altgr"],
    "yen": [0x15, "shift", "altgr"],
    "downarrow": [0x16, "altgr"],
    "uparrow": [0x16, "shift", "altgr"],
    "rightarrow": [0x17, "altgr"],
    "idotless": [0x17, "shift", "altgr"],
    "oslash": [0x18, "altgr"],
    "Ooblique": [0x18, "shift", "altgr"],
    "thorn": [0x19, "altgr"],
    "THORN": [0x19, "shift", "altgr"],
    "scaron": [0x1a],
    "Scaron": [0x1a, "shift"],
    "division": [0x1a, "altgr"],
    "dstroke": [0x1b],
    "Dstroke": [0x1b, "shift"],
    "multiply": [0x1b, "altgr"],
    "dead_macron": [0x1b, "shift", "altgr"],
    "ae": [0x1e, "altgr"],
    "AE": [0x1e, "shift", "altgr"],
    "ssharp": [[0x1f, "altgr"], [0x28, "altgr"]],
    "section": [[0x1f, "shift", "altgr"], [0x32, "altgr"]],
    "eth": [0x20, "altgr"],
    "ETH": [0x20, "shift", "altgr"],
    "bracketleft": [0x21, "altgr"],
    "ordfeminine": [0x21, "shift", "altgr"],
    "bracketright": [0x22, "altgr"],
    "ENG": [0x22, "shift", "altgr"],
    "hstroke": [0x23, "altgr"],
    "Hstroke": [0x23, "shift", "altgr"],
    "ccaron": [0x27],
    "Ccaron": [0x27, "shift"],
    "cacute": [0x28],
    "Cacute": [0x28, "shift"],
    "notsign": [0x29, "altgr"],
    "zcaron": [0x2b],
    "Zcaron": [0x2b, "shift"],
    "currency": [0x2b, "altgr"],
    "y": [0x2c],
    "guillemotleft": [0x2c, "altgr"],
    "guillemotright": [0x2d, "altgr"],
    "cent": [0x2e, "altgr"],
    "copyright": [0x2e, "shift", "altgr"],
    "at": [0x2f, "altgr"],
    "braceleft": [0x30, "altgr"],
    "braceright": [0x31, "altgr"],
    "masculine": [0x32, "shift", "altgr"],
    "comma": [0x33],
    "semicolon": [0x33, "shift"],
    "horizconnector": [0x33, "altgr"],
    "period": [0x34],
    "colon": [0x34, "shift"],
    "periodcentered": [0x34, "altgr"],
    "minus": [0x35],
    "underscore": [0x35, "shift"],
    "dead_belowdot": [0x35, "altgr"]
  },
  "sv": {
    "map": [0x0000041d],
    "section": [0x29],
    "onehalf": [0x29, "shift"],
    "exclam": [0x2, "shift"],
    "quotedbl": [0x3, "shift"],
    "at": [0x3, "altgr"],
    "numbersign": [0x4, "shift"],
    "sterling": [0x4, "altgr"],
    "currency": [0x5, "shift"],
    "dollar": [0x5, "altgr"],
    "percent": [0x6, "shift"],
    "ampersand": [0x7, "shift"],
    "slash": [0x8, "shift"],
    "braceleft": [0x8, "altgr"],
    "parenleft": [0x9, "shift"],
    "bracketleft": [0x9, "altgr"],
    "parenright": [0xa, "shift"],
    "bracketright": [0xa, "altgr"],
    "equal": [0xb, "shift"],
    "braceright": [0xb, "altgr"],
    "plus": [0xc],
    "question": [0xc, "shift"],
    "backslash": [0xc, "altgr"],
    "acute": [0xd],
    "dead_acute": [0xd],
    "grave": [0xd, "shift"],
    "dead_grave": [0xd, "shift"],
    "EuroSign": [0x12, "altgr"],
    "aring": [0x1a],
    "Aring": [0x1a, "shift"],
    "dead_diaeresis": [0x1b],
    "dead_circumflex": [0x1b, "shift"],
    "dead_tilde": [0x1b, "altgr"],
    "odiaeresis": [0x27],
    "Odiaeresis": [0x27, "shift"],
    "adiaeresis": [0x28],
    "Adiaeresis": [0x28, "shift"],
    "apostrophe": [0x2b],
    "asterisk": [0x2b, "shift"],
    "less": [0x56],
    "greater": [0x56, "shift"],
    "bar": [0x56, "altgr"],
    "mu": [0x32, "altgr"],
    "comma": [0x33],
    "semicolon": [0x33, "shift"],
    "period": [0x34],
    "colon": [0x34, "shift"],
    "minus": [0x35],
    "underscore": [0x35, "shift"]
  },
  "th": {
    "map": [0x41e],
    "exclam": [0x02, "shift"],
    "Thai_lakkhangyao": [0x02, "altgr"],
    "plus": [[0x02, "shift", "altgr"], [0x0d, "shift"]],
    "at": [0x03, "shift"],
    "slash": [[0x03, "altgr"], [0x35]],
    "Thai_leknung": [0x03, "shift", "altgr"],
    "numbersign": [0x04, "shift"],
    "minus": [[0x04, "altgr"], [0x0c]],
    "Thai_leksong": [0x04, "shift", "altgr"],
    "dollar": [0x05, "shift"],
    "Thai_phosamphao": [0x05, "altgr"],
    "Thai_leksam": [0x05, "shift", "altgr"],
    "percent": [[0x06, "shift"], [0x29, "shift", "altgr"]],
    "Thai_thothung": [0x06, "altgr"],
    "Thai_leksi": [0x06, "shift", "altgr"],
    "asciicircum": [0x07, "shift"],
    "Thai_sarau": [0x07, "altgr"],
    "Thai_sarauu": [0x07, "shift", "altgr"],
    "ampersand": [0x08, "shift"],
    "Thai_saraue": [0x08, "altgr"],
    "Thai_baht": [0x08, "shift", "altgr"],
    "asterisk": [0x09, "shift"],
    "Thai_khokhwai": [0x09, "altgr"],
    "Thai_lekha": [0x09, "shift", "altgr"],
    "parenleft": [[0x0a, "shift"], [0x2c, "shift", "altgr"]],
    "Thai_totao": [0x0a, "altgr"],
    "Thai_lekhok": [0x0a, "shift", "altgr"],
    "parenright": [[0x0b, "shift"], [0x2d, "shift", "altgr"]],
    "Thai_chochan": [0x0b, "altgr"],
    "Thai_lekchet": [0x0b, "shift", "altgr"],
    "underscore": [[0x0c, "shift"], [0x29, "altgr"]],
    "Thai_khokhai": [0x0c, "altgr"],
    "Thai_lekpaet": [0x0c, "shift", "altgr"],
    "equal": [0x0d],
    "Thai_chochang": [0x0d, "altgr"],
    "Thai_lekkao": [0x0d, "shift", "altgr"],
    "Thai_maiyamok": [0x10, "altgr"],
    "Thai_leksun": [0x10, "shift", "altgr"],
    "Thai_saraaimaimalai": [0x11, "altgr"],
    "quotedbl": [[0x11, "shift", "altgr"], [0x28, "shift"]],
    "Thai_saraam": [0x12, "altgr"],
    "Thai_dochada": [0x12, "shift", "altgr"],
    "Thai_phophan": [0x13, "altgr"],
    "Thai_thonangmontho": [0x13, "shift", "altgr"],
    "Thai_saraa": [0x14, "altgr"],
    "Thai_thothong": [0x14, "shift", "altgr"],
    "Thai_maihanakat": [0x15, "altgr"],
    "Thai_nikhahit": [0x15, "shift", "altgr"],
    "Thai_saraii": [0x16, "altgr"],
    "Thai_maitri": [0x16, "shift", "altgr"],
    "Thai_rorua": [0x17, "altgr"],
    "Thai_nonen": [0x17, "shift", "altgr"],
    "Thai_nonu": [0x18, "altgr"],
    "Thai_paiyannoi": [0x18, "shift", "altgr"],
    "Thai_yoyak": [0x19, "altgr"],
    "Thai_yoying": [0x19, "shift", "altgr"],
    "bracketleft": [0x1a],
    "braceleft": [0x1a, "shift"],
    "Thai_bobaimai": [0x1a, "altgr"],
    "Thai_thothan": [0x1a, "shift", "altgr"],
    "bracketright": [0x1b],
    "braceright": [0x1b, "shift"],
    "Thai_loling": [0x1b, "altgr"],
    "comma": [[0x1b, "shift", "altgr"], [0x33]],
    "Thai_fofan": [0x1e, "altgr"],
    "Thai_ru": [0x1e, "shift", "altgr"],
    "Thai_hohip": [0x1f, "altgr"],
    "Thai_khorakhang": [0x1f, "shift", "altgr"],
    "Thai_kokai": [0x20, "altgr"],
    "Thai_topatak": [0x20, "shift", "altgr"],
    "Thai_dodek": [0x21, "altgr"],
    "Thai_sarao": [0x21, "shift", "altgr"],
    "Thai_sarae": [0x22, "altgr"],
    "Thai_chochoe": [0x22, "shift", "altgr"],
    "Thai_maitho": [0x23, "altgr"],
    "Thai_maitaikhu": [0x23, "shift", "altgr"],
    "Thai_maiek": [0x24, "altgr"],
    "Thai_maichattawa": [0x24, "shift", "altgr"],
    "Thai_saraaa": [0x25, "altgr"],
    "Thai_sorusi": [0x25, "shift", "altgr"],
    "Thai_sosua": [0x26, "altgr"],
    "Thai_sosala": [0x26, "shift", "altgr"],
    "semicolon": [0x27],
    "colon": [0x27, "shift"],
    "Thai_wowaen": [0x27, "altgr"],
    "Thai_soso": [0x27, "shift", "altgr"],
    "apostrophe": [0x28],
    "Thai_ngongu": [0x28, "altgr"],
    "period": [[0x28, "shift", "altgr"], [0x34]],
    "grave": [0x29],
    "asciitilde": [0x29, "shift"],
    "ISO_First_Group": [0x2a, "shift"],
    "backslash": [0x2b],
    "bar": [0x2b, "shift"],
    "Thai_khokhuat": [0x2b, "altgr"],
    "Thai_khokhon": [0x2b, "shift", "altgr"],
    "Thai_phophung": [0x2c, "altgr"],
    "Thai_popla": [0x2d, "altgr"],
    "Thai_saraae": [0x2e, "altgr"],
    "Thai_choching": [0x2e, "shift", "altgr"],
    "Thai_oang": [0x2f, "altgr"],
    "Thai_honokhuk": [0x2f, "shift", "altgr"],
    "Thai_sarai": [0x30, "altgr"],
    "Thai_phinthu": [0x30, "shift", "altgr"],
    "Thai_sarauee": [0x31, "altgr"],
    "Thai_thanthakhat": [0x31, "shift", "altgr"],
    "Thai_thothahan": [0x32, "altgr"],
    "question": [[0x32, "shift", "altgr"], [0x35, "shift"]],
    "less": [0x33, "shift"],
    "Thai_moma": [0x33, "altgr"],
    "Thai_thophuthao": [0x33, "shift", "altgr"],
    "greater": [0x34, "shift"],
    "Thai_saraaimaimuan": [0x34, "altgr"],
    "Thai_lochula": [0x34, "shift", "altgr"],
    "Thai_fofa": [0x35, "altgr"],
    "Thai_lu": [0x35, "shift", "altgr"],
    "ISO_Last_Group": [0x36, "shift"]
  },
  "tr": {
    "map": [0x41f],
    "exclam": [0x02, "shift"],
    "onesuperior": [0x02, "altgr"],
    "exclamdown": [0x02, "shift", "altgr"],
    "apostrophe": [[0x03, "shift"], [0x30, "shift", "altgr"]],
    "at": [[0x03, "altgr"], [0x10, "altgr"]],
    "oneeighth": [0x03, "shift", "altgr"],
    "dead_circumflex": [[0x04, "shift"], [0x28, "altgr"]],
    "numbersign": [0x04, "altgr"],
    "sterling": [0x04, "shift", "altgr"],
    "plus": [0x05, "shift"],
    "dollar": [0x05, "altgr"],
    "percent": [0x06, "shift"],
    "onehalf": [0x06, "altgr"],
    "threeeighths": [0x06, "shift", "altgr"],
    "ampersand": [[0x07, "shift"], [0x25, "shift", "altgr"]],
    "asciicircum": [0x07, "altgr"],
    "fiveeighths": [0x07, "shift", "altgr"],
    "slash": [0x08, "shift"],
    "braceleft": [0x08, "altgr"],
    "seveneighths": [0x08, "shift", "altgr"],
    "parenleft": [0x09, "shift"],
    "bracketleft": [0x09, "altgr"],
    "trademark": [0x09, "shift", "altgr"],
    "parenright": [0x0a, "shift"],
    "bracketright": [0x0a, "altgr"],
    "plusminus": [0x0a, "shift", "altgr"],
    "equal": [0x0b, "shift"],
    "braceright": [0x0b, "altgr"],
    "degree": [0x0b, "shift", "altgr"],
    "asterisk": [0x0c],
    "question": [0x0c, "shift"],
    "backslash": [[0x0c, "altgr"], [0x29]],
    "questiondown": [0x0c, "shift", "altgr"],
    "minus": [0x0d],
    "underscore": [0x0d, "shift"],
    "dead_cedilla": [0x0d, "altgr"],
    "dead_ogonek": [0x0d, "shift", "altgr"],
    "Greek_OMEGA": [0x10, "shift", "altgr"],
    "lstroke": [[0x11, "altgr"], [0x26, "altgr"]],
    "Lstroke": [[0x11, "shift", "altgr"], [0x26, "shift", "altgr"]],
    "EuroSign": [0x12, "altgr"],
    "paragraph": [0x13, "altgr"],
    "registered": [0x13, "shift", "altgr"],
    "tslash": [0x14, "altgr"],
    "Tslash": [0x14, "shift", "altgr"],
    "leftarrow": [0x15, "altgr"],
    "yen": [0x15, "shift", "altgr"],
    "downarrow": [0x16, "altgr"],
    "uparrow": [0x16, "shift", "altgr"],
    "idotless": [0x17],
    "I": [0x17, "shift"],
    "rightarrow": [0x17, "altgr"],
    "oslash": [0x18, "altgr"],
    "Ooblique": [0x18, "shift", "altgr"],
    "thorn": [0x19, "altgr"],
    "THORN": [0x19, "shift", "altgr"],
    "gbreve": [0x1a],
    "Gbreve": [0x1a, "shift"],
    "dead_diaeresis": [0x1a, "altgr"],
    "dead_abovering": [0x1a, "shift", "altgr"],
    "udiaeresis": [0x1b],
    "Udiaeresis": [0x1b, "shift"],
    "asciitilde": [[0x1b, "altgr"], [0x29, "altgr"]],
    "dead_macron": [0x1b, "shift", "altgr"],
    "ae": [0x1e, "altgr"],
    "AE": [0x1e, "shift", "altgr"],
    "ssharp": [0x1f, "altgr"],
    "section": [0x1f, "shift", "altgr"],
    "eth": [0x20, "altgr"],
    "ETH": [0x20, "shift", "altgr"],
    "dstroke": [0x21, "altgr"],
    "ordfeminine": [0x21, "shift", "altgr"],
    "eng": [0x22, "altgr"],
    "ENG": [0x22, "shift", "altgr"],
    "hstroke": [0x23, "altgr"],
    "Hstroke": [0x23, "shift", "altgr"],
    "kra": [0x25, "altgr"],
    "scedilla": [0x27],
    "Scedilla": [0x27, "shift"],
    "dead_acute": [0x27, "altgr"],
    "dead_doubleacute": [0x27, "shift", "altgr"],
    "i": [0x28],
    "Iabovedot": [0x28, "shift"],
    "dead_caron": [0x28, "shift", "altgr"],
    "quotedbl": [0x29, "shift"],
    "comma": [0x2b],
    "semicolon": [0x2b, "shift"],
    "bar": [0x2b, "altgr"],
    "dead_breve": [0x2b, "shift", "altgr"],
    "guillemotleft": [0x2c, "altgr"],
    "less": [[0x2c, "shift", "altgr"], [0x33, "altgr"]],
    "guillemotright": [0x2d, "altgr"],
    "greater": [[0x2d, "shift", "altgr"], [0x34, "altgr"]],
    "cent": [0x2e, "altgr"],
    "copyright": [0x2e, "shift", "altgr"],
    "leftdoublequotemark": [0x2f, "altgr"],
    "grave": [0x2f, "shift", "altgr"],
    "rightdoublequotemark": [0x30, "altgr"],
    "mu": [0x32, "altgr"],
    "masculine": [0x32, "shift", "altgr"],
    "odiaeresis": [0x33],
    "Odiaeresis": [0x33, "shift"],
    "multiply": [0x33, "shift", "altgr"],
    "ccedilla": [0x34],
    "Ccedilla": [0x34, "shift"],
    "division": [0x34, "shift", "altgr"],
    "period": [0x35],
    "colon": [0x35, "shift"],
    "dead_belowdot": [0x35, "altgr"],
    "dead_abovedot": [0x35, "shift", "altgr"]
  }
};
exports.allKeyboardLayout = allKeyboardLayout;