#!/bin/sh
# Copyright (c) 2016 Synology Inc. All rights reserved.

PKG_NAME="Virtualization"
PKG_ROOT="/var/packages/$PKG_NAME"
GUESTSNAP_DB=""
GUESTSNAP_SQL_ROOT=${PKG_ROOT}"/target/etc/guestsnap_sql/"
INIT_SQL=${GUESTSNAP_SQL_ROOT}"/init.sql"
V2_SQL=${GUESTSNAP_SQL_ROOT}"/v2.sql"
V3_SQL=${GUESTSNAP_SQL_ROOT}"/v3.sql"
V4_SQL=${GUESTSNAP_SQL_ROOT}"/v4.sql"
V5_SQL=${GUESTSNAP_SQL_ROOT}"/v5.sql"
V6_SQL=${GUESTSNAP_SQL_ROOT}"/v6.sql"
V7_SQL=${GUESTSNAP_SQL_ROOT}"/v7.sql"
V8_SQL=${GUESTSNAP_SQL_ROOT}"/v8.sql"
V9_SQL=${GUESTSNAP_SQL_ROOT}"/v9.sql"
V10_SQL=${GUESTSNAP_SQL_ROOT}"/v10.sql"
V11_SQL=${GUESTSNAP_SQL_ROOT}"/v11.sql"
V12_SQL=${GUESTSNAP_SQL_ROOT}"/v12.sql"
V13_SQL=${GUESTSNAP_SQL_ROOT}"/v13.sql"
V14_SQL=${GUESTSNAP_SQL_ROOT}"/v14.sql"
V15_SQL=${GUESTSNAP_SQL_ROOT}"/v15.sql"
DB_VER='15';

to_v15()
{
	sqlite3 ${GUESTSNAP_DB} < ${V15_SQL}
}

to_v14()
{
	sqlite3 ${GUESTSNAP_DB} < ${V14_SQL}
}

to_v13()
{
	sqlite3 ${GUESTSNAP_DB} < ${V13_SQL}
}

to_v12()
{
	sqlite3 ${GUESTSNAP_DB} < ${V12_SQL}
}

to_v11()
{
	sqlite3 ${GUESTSNAP_DB} < ${V11_SQL}
}

to_v10()
{
	sqlite3 ${GUESTSNAP_DB} < ${V10_SQL}
}

to_v9()
{
	sqlite3 ${GUESTSNAP_DB} < ${V9_SQL}
}

to_v8()
{
	sqlite3 ${GUESTSNAP_DB} < ${V8_SQL}
}

to_v7()
{
	sqlite3 ${GUESTSNAP_DB} < ${V7_SQL}
}

to_v6()
{
	sqlite3 ${GUESTSNAP_DB} < ${V6_SQL}
}

to_v5()
{
	sqlite3 ${GUESTSNAP_DB} < ${V5_SQL}
}

to_v4()
{
	sqlite3 ${GUESTSNAP_DB} < ${V4_SQL}
}

to_v3()
{
	sqlite3 ${GUESTSNAP_DB} < ${V3_SQL}
}

to_v2()
{
	sqlite3 ${GUESTSNAP_DB} < ${V2_SQL}
}

init_db()
{
	if [ ! -f ${INIT_SQL} ]; then
		logger -p user.warn -t synoccc "Failed to init guestsnap.db since ${INIT_SQL} is not existed"
	else
		sqlite3 ${GUESTSNAP_DB} < ${INIT_SQL}
		logger -p user.info -t synoccc "Init guestsnap.db done"
	fi
}

upgrade_db()
{
	while true
	do
		local ver=`sqlite3 ${GUESTSNAP_DB} "SELECT value FROM db_ver;"`;

		case ${ver} in
			1)
				to_v2
				;;
			2)
				to_v3
				;;
			3)
				to_v4
				;;
			4)
				to_v5
				;;
			5)
				to_v6
				;;
			6)
				to_v7
				;;
			7)
				to_v8
				;;
			8)
				to_v9
				;;
			9)
				to_v10
				;;
			10)
				to_v11
				;;
			11)
				to_v12
				;;
			12)
				to_v13
				;;
			13)
				to_v14
				;;
			14)
				to_v15
				;;
			$DB_VER)
				break
				;;
			*)
				logger -p user.warn -t synoccc "Failed to upgrade db since bad ver [${ver}]"
				break
				;;
		esac
		logger -p user.warn -t synoccc "Upgrade ${GUESTSNAP_DB} to ver[$(($ver+1))]"
	done
}

repair_db()
{
	GUESTSNAP_DB="$1/guestsnap.db"

	if [ ! -f "${GUESTSNAP_DB}" ]; then
		logger -p user.info -t synoccc "guestsnap.db not found. Initing db."
		init_db
		return
	else
		local existed=`sqlite3 ${GUESTSNAP_DB} "SELECT 1 FROM sqlite_master WHERE type='table' AND name='db_ver';"`

		if [ -z "$existed" ]; then
			logger -p user.info -t synoccc "GuestSnapshot table not found. Initing db."
			init_db
			return
		else
			local ver=`sqlite3 ${GUESTSNAP_DB} "SELECT value FROM db_ver;"`;
			if [ -z "$ver" ]; then
				init_db
			else
				upgrade_db
			fi
		fi
	fi
}

case "$1" in
repair_db)
	repair_db $2
	;;
*)
	echo "usage: $0 repair_db <dir>"
	exit 1
;;
esac
