#!/bin/sh

PKG_ROOT="/var/packages/Virtualization"
SYNODR_TOOL=${PKG_ROOT}"/target/sbin/synodr"
REPLICA_ETC=${PKG_ROOT}"/etc/"
PLAN_REPORT=${REPLICA_ETC}"/plan/"
REPLICA_DB=${REPLICA_ETC}"/replica.db"
REPLICA_SQL_ROOT=${PKG_ROOT}"/target/replica_sql/"
INIT_SQL=${REPLICA_SQL_ROOT}"/init_db.sql"
V2_SQL=${REPLICA_SQL_ROOT}"/v2.sql"
V3_SQL=${REPLICA_SQL_ROOT}"/v3.sql"
V4_SQL=${REPLICA_SQL_ROOT}"/v4.sql"
V5_SQL=${REPLICA_SQL_ROOT}"/v5.sql"
V6_SQL=${REPLICA_SQL_ROOT}"/v6.sql"
V7_SQL=${REPLICA_SQL_ROOT}"/v7.sql"
V8_SQL=${REPLICA_SQL_ROOT}"/v8.sql"
V6_REPAIR_SQL=${REPLICA_SQL_ROOT}"/v6_repair.sql"
DB_VER='8';
SYNODR_TMP="/tmp/.synodr/Virtualization"

to_v2()
{
	for record in `sqlite3 $REPLICA_DB "SELECT plan_id,op_status from plan;"`; do
		local plan_id=`echo ${record} | cut -d"|" -f1`
		if [ -z ${plan_id} ]; then
			continue
		fi

		local op_status=`echo ${record} | cut -d"|" -f2`
		local plan_report="${PLAN_REPORT}/${plan_id}"
		local site_op_status="${PLAN_REPORT}/${plan_id}/site_op_status"

		if [ ! -d ${plan_report} ]; then
			mkdir -p ${plan_report}
		fi

		if [ -f "${site_op_status}" ]; then
			continue;
		fi

		if [ -z "${op_status}" ]; then
			op_status=1
		fi
		echo "{\"op_status\": ${op_status}}" > ${site_op_status}
	done
	sqlite3 ${REPLICA_DB} < ${V2_SQL}
}

to_v3()
{
	sqlite3 ${REPLICA_DB} < ${V3_SQL}
}

to_v4()
{
	sqlite3 ${REPLICA_DB} < ${V4_SQL}
}

to_v5()
{
	sqlite3 ${REPLICA_DB} < ${V5_SQL}
}

to_v6()
{
	sqlite3 ${REPLICA_DB} < ${V6_SQL}
}

to_v7()
{
	sqlite3 ${REPLICA_DB} < ${V7_SQL}
}

to_v8()
{
	sqlite3 ${REPLICA_DB} < ${V8_SQL}
}

repair_v6()
{
	sqlite3 ${REPLICA_DB} < ${V6_REPAIR_SQL}
}


init_db()
{
	if [ ! -f ${INIT_SQL} ]; then
		logger -p user.warn -t synodr "Failed to init synodr replica.db since ${INIT_SQL} is not existed"
	else
		sqlite3 ${REPLICA_DB} < ${INIT_SQL}
		logger -p user.info -t synodr "Init synodr replica.db done"
	fi
}

upgrade_db()
{
	while true
	do
		local ver=`sqlite3 ${REPLICA_DB} "SELECT value FROM db_ver;" | head -1`;

		repair_data $ver

		case ${ver} in
			1)
				to_v2
				;;
			2)
				to_v3
				;;
			3)
				to_v4
				;;
			4)
				to_v5
				;;
			5)
				to_v6
				;;
			6)
				to_v7
				;;
			7)
				to_v8
				;;
			$DB_VER)
				break
				;;
			*)
				logger -p user.warn -t synodr "Failed to upgrade db to [${DB_VER}] since bad ver [${ver}]"
				break
				;;
		esac
		logger -p user.warn -t synodr "Upgrade ${REPLICA_DB} to ver[$(($ver+1))]"
	done
}

repair_data()
{
	case $1 in
		$DB_VER)
			repair_v6
			;;
	esac
}

repair_db()
{
	if [ ! -f "${REPLICA_DB}" ]; then
		logger -p user.info -t synodr "    Db not found. Initing db."
		init_db
		return
	else
		local existed=`sqlite3 ${REPLICA_DB} "SELECT 1 FROM sqlite_master WHERE type='table' AND name='db_ver';"`

		if [ -z "$existed" ]; then
			logger -p user.info -t synodr "    Table not found. Initing db."
			init_db
			return
		else
			local ver=`sqlite3 ${REPLICA_DB} "SELECT value FROM db_ver;" | head -1`;
			if [ -z "$ver" ]; then
				init_db
			else
				upgrade_db
			fi
		fi
	fi
}

reset_op()
{
	rm -rf "$SYNODR_TMP"
}

repair_replication()
{
	if [ -x "${SYNODR_TOOL}" ]; then
		${SYNODR_TOOL} site repair
	fi
}

resume_window_sync()
{
	if [ -x "${SYNODR_TOOL}" ]; then
		${SYNODR_TOOL} site window_sync true
	fi
}

start()
{
	logger -p user.info -t synodr " ---> Start Data Protection Replication Check"

	repair_db
	reset_op
	repair_replication
	resume_window_sync

	logger -p user.info -t synodr " <--- Finish Data Protection Replication Check"
}

case "$1" in
start)
	start
;;
*)
	echo "usage: $0 [start]" >&2
	exit 1
;;
esac
