#!/bin/sh

PKG_NAME="Virtualization"
PKG_ROOT="/var/packages/$PKG_NAME"
PKG_ETC=${PKG_ROOT}"/etc/"
DRGROUP_DB=""
DRGROUP_SQL_ROOT=${PKG_ROOT}"/target/etc/drgroup_sql/"
INIT_SQL=${DRGROUP_SQL_ROOT}"/init_db.sql"
V2_SQL=${DRGROUP_SQL_ROOT}"/v2.sql"
V3_SQL=${DRGROUP_SQL_ROOT}"/v3.sql"
DB_VER='3';

to_v2()
{
	sqlite3 ${DRGROUP_DB} < ${V2_SQL}
}

to_v3()
{
	sqlite3 ${DRGROUP_DB} < ${V3_SQL}
}

init_db()
{
	if [ ! -f ${INIT_SQL} ]; then
		logger -p user.warn -t synodrgroup "Failed to init drgroup.db since ${INIT_SQL} is not existed"
	else
		sqlite3 ${DRGROUP_DB} < ${INIT_SQL}
		logger -p user.info -t synodrgroup "Init drgroup.db done"
	fi
}

upgrade_db()
{
	while true
	do
		local ver=`sqlite3 ${DRGROUP_DB} "SELECT value FROM db_ver;"`;

		case ${ver} in
			1)
				to_v2
				;;
			2)
				to_v3
				;;
			$DB_VER)
				break
				;;
			*)
				logger -p user.warn -t synodrgroup "Failed to upgrade db since bad ver [${ver}]"
				break
				;;
		esac
		logger -p user.warn -t synodrgroup "Upgrade ${DRGROUP_DB} to ver[$(($ver+1))]"
	done
}

repair_db()
{
	if [ ! -d "$1" ]; then
		logger -p user.err -t synodrgroup "[$1] is not dir."
		return
	fi

	DRGROUP_DB="$1/drgroup.db"

	if [ ! -f "${DRGROUP_DB}" ]; then
		logger -p user.info -t synodrgroup "DRGroup db not found. Initing db."
		init_db
		return
	else
		local existed=`sqlite3 ${DRGROUP_DB} "SELECT 1 FROM sqlite_master WHERE type='table' AND name='db_ver';"`

		if [ -z "$existed" ]; then
			logger -p user.info -t synodrgroup "DRGroup table not found. Initing db."
			init_db
			return
		else
			local ver=`sqlite3 ${DRGROUP_DB} "SELECT value FROM db_ver;"`;
			if [ -z "$ver" ]; then
				init_db
			else
				upgrade_db
			fi
		fi
	fi
}

case "$1" in
repair_db)
	repair_db $2
	;;
*)
	echo "usage: $0 repair_db <dir>"
	exit 1
;;
esac
